﻿* Encoding: UTF-8.

**************************************************************************************************************
*** SINTAXIS PARA EL CÁLCULO DE LOS ESTADÍSTICOS, TABULADOS E INDICADORES
*** DEL MÓDULO DE INFORMACIÓN AMBIENTAL EN AGRICULTURA DE LA ENCUESTA
*** DE SUPERFICIE Y PRODUCCIÓN AGROPECUARIA CONTINUA - ESPAC 2018.
*** REALIZADA POR: RAMIRO BENAVIDES - DEAGA.
*** 02 DE MAYO DE 2019.
**************************************************************************************************************

* (0.1) CREACIÓN DE IDENTIFICADOR ÚNICO DE ENCUESTA.
* ABRIR LA BASE DE DATOS DEL MÓDULO AMBIENTAL (ambnac2017.sav).

SORT CASES BY ual_prov ual_cant ual_parr ual_estr ual_segm al_ncues.

STRING identif (A17).
COMPUTE identif = CONCAT(LTRIM(RTRIM(ual_prov)), LTRIM(RTRIM(ual_cant)), LTRIM(RTRIM(ual_parr)), LTRIM(RTRIM(ual_estr)),
LTRIM(RTRIM(ual_segm)), LTRIM(RTRIM(al_ncues))).

SORT CASES BY identif.
COMPUTE id_unico = (LAG(identif) <> identif).
FREQUENCIES id_unico.

* (0.2) LLEVAR LA VARIABLE DE INSTRUCCIÓN (cg_k102) DESDE LA BASE DE CARACTERÍSTICAS GENERALES
* HASTA LA BASE DEL MÓDULO AMBIENTAL.

DATASET NAME ambientales. /* Correr esta línea después de pasar el enfoque a la base de Ambientales.

* ABRIR BASE DE CARACTERÍSTICAS GENERALES, SIN CERRAR LA BASE DEL MÓDULO AMBIENTAL.
DATASET NAME caracteristicas. /* Correr esta línea después de pasar el enfoque a la base de Características Generales.
DATASET ACTIVATE ambientales.
COMPUTE ORIGINAL = 1. /* Variable indicadora de los registros originales en la base de Ambientales. Útil para fusión de bases.
SORT CASES BY identif.

* CREACIÓN DE IDENTIFICADOR ÚNICO DE ENCUESTA EN LA BASE DE CARACTERÍSTICAS GENERALES.
DATASET ACTIVATE caracteristicas.

SORT CASES BY ual_prov ual_cant ual_parr ual_estr ual_segm al_ncues.

STRING identif (A17).
COMPUTE identif = CONCAT(LTRIM(RTRIM(ual_prov)), LTRIM(RTRIM(ual_cant)), LTRIM(RTRIM(ual_parr)), LTRIM(RTRIM(ual_estr)),
LTRIM(RTRIM(ual_segm)), LTRIM(RTRIM(al_ncues))).

SORT CASES BY identif.
COMPUTE id_unico = (LAG(identif) <> identif).
FREQUENCIES id_unico.
SORT CASES BY identif.

* Fusión de la base "Ambientales" con la base "Características Generales" para llevar a la primera la
* variables de Nivel de Instrucción (cg_k102) de la Persona Productora (PP).

DATASET ACTIVATE ambientales.
MATCH FILES /FILE=*
  /FILE='caracteristicas'
  /RENAME (al_ncues anio_enc cg_codcor cg_dista_pre_viv cg_k100 cg_k101 cg_produpa cg_se_define 
    cg_segsoccam cg_superficie cg_unidadmedida cg_vive_predio_pr cod_encu id_unico ual_cant ual_estr 
    ual_parr ual_prov ual_segm = d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18) 
  /BY identif
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18.
EXECUTE.

FREQUENCIES cg_k102. /* Revisión de la variable transportada a la base de Ambientales.
SELECT IF (ORIGINAL = 1). /* Después de la fusión, se mantienen únicamente los registros originales de la base de Ambientales.
EXECUTE.

SAVE OUTFILE='C:\ESPAC\MODULO_AMB\ambnac2018.sav' /* Guardar BDD del Módulo Ambiental para utilizarla posteriormente.
 /COMPRESSED.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* (0) PREÁMBULO: CÁLCULO NO PUBLICADO DE LA SUPERFICIE AGROPECUARIA DEL ECUADOR.

*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav)***.

DATASET CLOSE ambientales.
DATASET CLOSE caracteristicas.

DATASET NAME permanentes.

WEIGHT OFF.
FILTER OFF.
COMPUTE cultiv_perm = (rc_clacul >= 400 & rc_clacul <= 499). /* Los cultivos permanentes están en este rango de productos. 
FREQUENCIES cultiv_perm.

FILTER BY cultiv_perm.
WEIGHT BY fact_exp_fin.

DESCRIPTIVES VARIABLES=cp_k409ha
  /STATISTICS=MEAN SUM STDDEV MIN MAX.

*** Se obtuvo 1'464'589.4383 ha. de cultivos permanentes.

*** ABRIR BASE DE PASTOS CULTIVADOS (pcnac2018.sav)***.

DATASET NAME pastos.

WEIGHT OFF.
FILTER OFF.
COMPUTE pastos_cultiv = (rc_clacul >= 751 & rc_clacul <= 780). /* Los pastos cultivados están en este rango de productos. 
FREQUENCIES pastos_cultiv.

FILTER BY pastos_cultiv.
WEIGHT BY fact_exp_fin.

DESCRIPTIVES VARIABLES=pc_k409ha
  /STATISTICS=MEAN SUM STDDEV MIN MAX.

*** Se obtuvo 2'382'448.3560 ha. de pastos cultivados, EN LA BASE DE PASTOS CULTIVADOS.

*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

DATASET NAME transitorios.

WEIGHT OFF.
FILTER OFF.
COMPUTE cultiv_tran = (ct_clacul >= 500 & ct_clacul <= 599). /* Los cultivos transitorios están en este rango de productos. 
FREQUENCIES cultiv_tran.

USE ALL.
FILTER BY cultiv_tran.
WEIGHT BY fact_exp_fin.

DESCRIPTIVES VARIABLES=ct_k510h
  /STATISTICS=MEAN SUM STDDEV MIN MAX.

*** Se obtuvo 941'279.9184 ha. de cultivos transitorios.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* SECCIÓN 1. CULTIVOS.

* TABLAS 1 y 2: SUPERFICIE PRODUCTIVA PERDIDA A NIVEL NACIONAL (ha).

*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav) ***.

DATASET ACTIVATE permanentes.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

RENAME VARIABLES (nuevacondicion = cp_nuevacondicion).
RENAME VARIABLES (superdida = cp_superdida).

FREQUENCIES cp_nuevacondicion. /* Condición del cultivo permanente: 1 = Solo; 2 = Asociado; 3 = Invernadero.
FREQUENCIES cp_k412. /* Razón principal de pérdida: 1 = Sequía; 2 = Helada; 3 = Plagas; 4 = Enfermedades; 5 = Inundación; 6 = Otra.

WEIGHT BY fact_exp_fin.

***** TABLA 1. SUPERFICIE PERDIDA EN CULTIVOS PERMANENTES, POR FORMA DE SIEMBRA O PLANTACIÓN Y SEGÚN DIFERENTES CAUSAS DE PÉRDIDA

FILTER BY cultiv_perm.

CTABLES
  /VLABELS VARIABLES=cp_nuevacondicion cp_k412 cp_superdida DISPLAY=LABEL
  /TABLE cp_nuevacondicion BY cp_k412 > cp_superdida [SUM, ROWPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=cp_nuevacondicion ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=cp_k412 [1, 2, 3, 4, 5, 6] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE=' SUPERFICIE PERDIDA EN CULTIVOS PERMANENTES, POR FORMA DE SIEMBRA O PLANTACIÓN Y SEGÚN DIFERENTES CAUSAS DE PÉRDIDA'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

FILTER OFF.

*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

DATASET ACTIVATE transitorios.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

RENAME VARIABLES (superdida = ct_superdida).

FREQUENCIES ct_nuevacondicion. /* Condición del cultivo transitorio: 1 = Solo; 2 = Asociado; 3 = Invernadero.
VALUE LABELS ct_k512 1'Sequía' 2'Helada' 3'Plagas' 4'Enfermedades' 5'Inundación' 6'Otra'.
FREQUENCIES ct_k512. /* Razón principal de pérdida: 1 = Sequía; 2 = Helada; 3 = Plagas; 4 = Enfermedades; 5 = Inundación; 6 = Otra.

WEIGHT BY fact_exp_fin.

***** TABLA 2. SUPERFICIE PERDIDA EN CULTIVOS TRANSITORIOS, POR FORMA DE SIEMBRA O PLANTACIÓN Y SEGÚN DIFERENTES CAUSAS DE PÉRDIDA

FILTER BY cultiv_tran.

CTABLES
  /VLABELS VARIABLES=ct_nuevacondicion ct_k512 ct_superdida DISPLAY=LABEL
  /TABLE ct_nuevacondicion BY ct_k512 > ct_superdida [SUM, ROWPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=ct_nuevacondicion ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=ct_k512 [1, 2, 3, 4, 5, 6] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE=' SUPERFICIE PERDIDA EN CULTIVOS TRANSITORIOS, POR FORMA DE SIEMBRA O PLANTACIÓN Y SEGÚN DIFERENTES CAUSAS DE PÉRDIDA'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

FILTER OFF.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 3. SUPERFICIE DONDE SE PRACTICÓ LA QUEMA EN EL TERRENO PARA LA PREPARACIÓN DEL SUELO EN CULTIVOS TRANSITORIOS.

*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

FREQUENCIES ct_k510h. /* Superficie sembrada (ha) en cultivos transitorios.
FREQUENCIES ct_prepa_suelo. /* Terrenos donde se practicó la quema para la preparación del suelo.

FILTER BY cultiv_tran.

WEIGHT BY fact_exp_fin.

***** TABLA 3. SUPERFICIE DONDE SE PRACTICÓ LA QUEMA EN EL TERRENO PARA LA PREPARACIÓN DEL SUELO EN CULTIVOS TRANSITORIOS.

CTABLES
  /VLABELS VARIABLES=ct_prepa_suelo ct_k510h DISPLAY=LABEL
  /TABLE ct_prepa_suelo BY ct_k510h [SUM, COLPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=ct_prepa_suelo ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
   /TITLES
    TITLE=' SUPERFICIE DONDE SE PRACTICÓ LA QUEMA EN EL TERRENO PARA LA PREPARACIÓN DEL SUELO EN CULTIVOS TRANSITORIOS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

FILTER OFF.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 4. SUPERFICIE SEMBRADA EN CULTIVOS TRANSITORIOS, POR TIPO DE MAQUINARIA USADA PARA LA PREPARACIÓN DEL SUELO.

*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

FREQUENCIES ct_presueuti. /* Tipo de maquinaria usada para la preparación del suelo.

FILTER BY cultiv_tran.

WEIGHT BY fact_exp_fin.

***** TABLA 4. SUPERFICIE SEMBRADA EN CULTIVOS TRANSITORIOS, POR TIPO DE MAQUINARIA USADA PARA LA PREPARACIÓN DEL SUELO.

CTABLES
  /VLABELS VARIABLES=ct_presueuti ct_k510h DISPLAY=LABEL
  /TABLE ct_presueuti BY ct_k510h [SUM, COLPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=ct_presueuti ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
   /TITLES
    TITLE=' SUPERFICIE SEMBRADA EN CULTIVOS TRANSITORIOS, POR TIPO DE MAQUINARIA USADA PARA LA PREPARACIÓN DEL SUELO'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

FILTER OFF.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 5. SUPERFICIE PLANTADA POR FORMA DE SIEMBRA O PLANTACIÓN Y SEGÚN TIPO DE SEMILLA USADA EN CULTIVOS PERMANENTES
*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav) ***.

DATASET ACTIVATE permanentes.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

FREQUENCIES cp_k408. /* Semilla de más uso: 1 = Común; 2 = Mejorada; 3 = Híbrida nacional; 4 = Híbrida internacional.

RECODE cp_k408 (SYSMIS = 1) (ELSE = COPY) INTO cp_k408_R.
VALUE LABELS cp_k408_R 1'Común' 2'Mejorada' 3'Híbrida nacional' 4'Híbrida internacional'.

FILTER BY cultiv_perm.

WEIGHT BY fact_exp_fin.

***** TABLA 5. SUPERFICIE PLANTADA POR FORMA DE SIEMBRA O PLANTACIÓN Y SEGÚN TIPO DE SEMILLA USADA EN CULTIVOS PERMANENTES.

CTABLES
  /VLABELS VARIABLES=cp_nuevacondicion cp_k408_R cp_k409ha DISPLAY=LABEL
  /TABLE cp_nuevacondicion [C] BY cp_k408_R > cp_k409ha [SUM]
  /CATEGORIES VARIABLES=cp_nuevacondicion cp_k408_R ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
   /TITLES
    TITLE='SUPERFICIE PLANTADA POR FORMA DE SIEMBRA O PLANTACIÓN Y SEGÚN TIPO DE SEMILLA USADA EN CULTIVOS PERMANENTES'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

FILTER OFF.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 6. SUPERFICIE SEMBRADA POR FORMA DE SIEMBRA O PLANTACIÓN Y SEGÚN TIPO DE SEMILLA USADA EN CULTIVOS TRANSITORIOS
*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav)  ***.

DATASET ACTIVATE transitorios.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

FREQUENCIES ct_k506. /* Semilla de más uso: 1 = Común; 2 = Mejorada; 3 = Certificada; 4 = Híbrida nacional; 5 = Híbrida internacional.

RECODE ct_k506 (SYSMIS = 1) (ELSE = COPY) INTO ct_k506_R.
VALUE LABELS ct_k506_R 1'Común' 2'Mejorada' 3'Certificada' 4'Híbrida nacional' 5'Híbrida internacional'.

FILTER BY cultiv_tran.

WEIGHT BY fact_exp_fin.

***** TABLA 6. SUPERFICIE SEMBRADA POR FORMA DE SIEMBRA O PLANTACIÓN Y SEGÚN TIPO DE SEMILLA USADA EN CULTIVOS TRANSITORIOS.

CTABLES
  /VLABELS VARIABLES=ct_nuevacondicion ct_k506_R ct_k510h DISPLAY=LABEL
  /TABLE ct_nuevacondicion [C] BY ct_k506_R > ct_k510h [SUM]
  /CATEGORIES VARIABLES=ct_nuevacondicion ct_k506_R ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
   /TITLES
    TITLE='SUPERFICIE SEMBRADA POR FORMA DE SIEMBRA O PLANTACIÓN Y SEGÚN TIPO DE SEMILLA USADA EN CULTIVOS TRANSITORIOS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

FILTER OFF.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 7. SUPERFICIE PLANTADA O SEMBRADA, POR USO DE INSUMOS AGRÍCOLAS (ORGÁNICOS Y QUÍMICOS)

*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav) ***.

DATASET ACTIVATE permanentes.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

COMPUTE ORG = ((cp_forg = 1 OR cp_porg = 1) AND (cp_fqui = 2 AND cp_pqui = 2)). /* Uso orgánico puro.
COMPUTE QUI = ((cp_fqui = 1 OR cp_pqui = 1) AND (cp_forg = 2 AND cp_porg = 2)). /* Uso químico puro.
COMPUTE NIN = (cp_forg = 2 AND cp_porg = 2 AND cp_fqui = 2 AND cp_pqui = 2). /* Uso sin agrosustancias.
COMPUTE TOD = ~(ORG = 1 OR QUI = 1 OR NIN = 1). /* Uso con todas las agrosustancias.
FREQUENCIES ORG QUI NIN TOD.

VARIABLE LABELS ORG "Uso de insumos orgánicos".
VARIABLE LABELS QUI "Uso de insumos químicos".
VARIABLE LABELS TOD "Uso de insumos orgánicos y químicos".
VARIABLE LABELS NIN "No usan ningún tipo de insumo".
VALUE LABELS ORG QUI NIN TOD 0'No' 1'Sí'.

FILTER BY cultiv_perm.

WEIGHT BY fact_exp_fin.

***** TABLA 7A. SUPERFICIE PLANTADA POR USO DE INSUMOS AGRÍCOLAS (ORGÁNICOS Y QUÍMICOS) EN CULTIVOS PERMANENTES.

CTABLES
  /VLABELS VARIABLES=ORG QUI TOD NIN cp_k409ha DISPLAY=LABEL
  /TABLE ORG + QUI + TOD + NIN BY cp_k409ha [SUM]
  /CATEGORIES VARIABLES=ORG [1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=QUI [1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=TOD [1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=NIN [1] EMPTY=EXCLUDE
   /TITLES
    TITLE='SUPERFICIE PLANTADA (ha) POR USO DE INSUMOS AGRÍCOLAS (ORGÁNICOS Y QUÍMICOS) EN CULTIVOS PERMANENTES'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

DATASET ACTIVATE transitorios.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

COMPUTE ORG = ((ct_forg = 1 OR ct_porg = 1) AND (ct_fqui = 2 AND ct_pqui = 2)). /* Uso orgánico puro.
COMPUTE QUI = ((ct_fqui = 1 OR ct_pqui = 1) AND (ct_forg = 2 AND ct_porg = 2)). /* Uso químico puro.
COMPUTE NIN = (ct_forg = 2 AND ct_porg = 2 AND ct_fqui = 2 AND ct_pqui = 2). /* Uso sin agrosustancias.
COMPUTE TOD = ~(ORG = 1 OR QUI = 1 OR NIN = 1). /* Uso con todas las agrosustancias.
FREQUENCIES ORG QUI NIN TOD.

VARIABLE LABELS ORG "Uso de insumos orgánicos".
VARIABLE LABELS QUI "Uso de insumos químicos".
VARIABLE LABELS TOD "Uso de insumos orgánicos y químicos".
VARIABLE LABELS NIN "No usan ningún tipo de insumo".
VALUE LABELS ORG QUI NIN TOD 0'No' 1'Sí'.

FILTER BY cultiv_tran.

WEIGHT BY fact_exp_fin.

***** TABLA 7B. SUPERFICIE SEMBRADA POR USO DE INSUMOS AGRÍCOLAS (ORGÁNICOS Y QUÍMICOS) EN CULTIVOS TRANSITORIOS.

CTABLES
  /VLABELS VARIABLES=ORG QUI TOD NIN ct_k510h DISPLAY=LABEL
  /TABLE ORG + QUI + TOD + NIN BY ct_k510h [SUM]
  /CATEGORIES VARIABLES=ORG [1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=QUI [1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=TOD [1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=NIN [1] EMPTY=EXCLUDE
  /TITLES
    TITLE='SUPERFICIE SEMBRADA (ha) POR USO DE INSUMOS AGRÍCOLAS (ORGÁNICOS Y QUÍMICOS) EN CULTIVOS TRANSITORIOS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 8. SUPERFICIE PLANTADA POR CONDICIÓN DE CULTIVO Y SEGÚN TIPO DE FERTILIZANTE O FITOSANITARIO EN CULTIVOS PERMANENTES.

*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav) ***.

DATASET ACTIVATE permanentes.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

FILTER BY cultiv_perm.

WEIGHT BY fact_exp_fin.

***** TABLA 8. SUPERFICIE PLANTADA POR CONDICIÓN DE CULTIVO Y SEGÚN TIPO DE FERTILIZANTE O FITOSANITARIO EN CULTIVOS PERMANENTES.

CTABLES
  /VLABELS VARIABLES=cp_k404 cp_k409ha cp_forg cp_fqui cp_porg cp_pqui DISPLAY=LABEL
  /TABLE cp_k404 [C] BY cp_k409ha [S][SUM] > (cp_forg [C] + cp_fqui [C]) + cp_k409ha [S][SUM] > (cp_porg [C] + cp_pqui [C])
  /CATEGORIES VARIABLES=cp_k404 ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=cp_forg cp_fqui cp_porg cp_pqui [1] EMPTY=INCLUDE
  /TITLES
    TITLE='SUPERFICIE PLANTADA (ha) POR CONDICIÓN DE CULTIVO Y SEGÚN TIPO DE FERTILIZANTE O FITOSANITARIO'  'C. PERMANENTES'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 9. SUPERFICIE SEMBRADA POR CONDICIÓN DE CULTIVO Y SEGÚN TIPO DE FERTILIZANTE O FITOSANITARIO EN CULTIVOS TRANSITORIOS.

*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

DATASET ACTIVATE transitorios.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

FILTER BY cultiv_tran.

WEIGHT BY fact_exp_fin.

***** TABLA 9. SUPERFICIE SEMBRADA POR CONDICIÓN DE CULTIVO Y SEGÚN TIPO DE FERTILIZANTE O FITOSANITARIO EN CULTIVOS TRANSITORIOS.

CTABLES
  /VLABELS VARIABLES=ct_nuevacondicion ct_k510h ct_forg ct_fqui ct_porg ct_pqui DISPLAY=LABEL
  /TABLE ct_nuevacondicion [C] BY ct_k510h [S][SUM] > (ct_forg [C] + ct_fqui [C]) + ct_k510h [S][SUM] > (ct_porg [C] + ct_pqui [C])
  /CATEGORIES VARIABLES=ct_nuevacondicion ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=ct_forg ct_fqui ct_porg ct_pqui [1] EMPTY=INCLUDE
  /TITLES
    TITLE='SUPERFICIE SEMBRADA (ha) POR CONDICIÓN DE CULTIVO Y SEGÚN TIPO DE FERTILIZANTE O FITOSANITARIO'  'C. TRANSITORIOS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 10. SUPERFICIE PLANTADA O SEMBRADA POR TIPO DE CULTIVO Y SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS

*** ABRIR BASE DE PASTOS CULTIVADOS (pcnac2018.sav) ***.

DATASET ACTIVATE pastos.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

COMPUTE ORG = ((cp_forg = 1 OR cp_porg = 1) AND (cp_fqui = 2 AND cp_pqui = 2)). /* Uso orgánico puro.
COMPUTE QUI = ((cp_fqui = 1 OR cp_pqui = 1) AND (cp_forg = 2 AND cp_porg = 2)). /* Uso químico puro.
COMPUTE NIN = (cp_forg = 2 AND cp_porg = 2 AND cp_fqui = 2 AND cp_pqui = 2). /* Uso sin agrosustancias.
COMPUTE TOD = ~(ORG = 1 OR QUI = 1 OR NIN = 1). /* Uso con todas las agrosustancias.
FREQUENCIES ORG QUI NIN TOD.

VARIABLE LABELS ORG "Uso de insumos orgánicos".
VARIABLE LABELS QUI "Uso de insumos químicos".
VARIABLE LABELS TOD "Uso de insumos orgánicos y químicos".
VARIABLE LABELS NIN "No usan ningún tipo de insumo".
VALUE LABELS ORG QUI NIN TOD 0'No' 1'Sí'.

FILTER BY pastos_cultiv.

WEIGHT BY fact_exp_fin.

***** TABLA 10, FILA 1: SUPERFICIE PLANTADA (ha) EN PASTOS CULTIVADOS SEGÚN USO DE INSUMOS ORGÁNICOS O QUÏMICOS.

CTABLES
  /VLABELS VARIABLES=ORG pc_k409ha QUI DISPLAY=LABEL
  /TABLE BY ORG [C] > pc_k409ha [S][SUM] + QUI [C] > pc_k409ha [S][SUM]
  /CATEGORIES VARIABLES=ORG [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=QUI [1] EMPTY=INCLUDE
  /TITLES
    TITLE='SUPERFICIE PLANTADA (ha) SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS'  'Pastos Cultivados'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav) ***.

DATASET ACTIVATE permanentes.

FILTER BY cultiv_perm.

WEIGHT BY fact_exp_fin.

***** TABLA 10, FILA 2: SUPERFICIE PLANTADA (ha) EN CULTIVOS PERMANENTES SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS.

CTABLES
  /VLABELS VARIABLES=ORG cp_k409ha QUI DISPLAY=LABEL
  /TABLE BY ORG [C] > cp_k409ha [S][SUM] + QUI [C] > cp_k409ha [S][SUM]
  /CATEGORIES VARIABLES=ORG [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=QUI [1] EMPTY=INCLUDE
  /TITLES
    TITLE='SUPERFICIE PLANTADA (ha) SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS'  'Cultivos Permanentes'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

DATASET ACTIVATE transitorios.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

FILTER BY cultiv_tran.

WEIGHT BY fact_exp_fin.

***** TABLA 10, FILA 3: SUPERFICIE SEMBRADA (ha) EN CULTIVOS TRANSITORIOS SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS.

CTABLES
  /VLABELS VARIABLES=ORG ct_k510h QUI DISPLAY=LABEL
  /TABLE BY ORG [C] > ct_k510h [S][SUM] + QUI [C] > ct_k510h [S][SUM]
  /CATEGORIES VARIABLES=ORG [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=QUI [1] EMPTY=INCLUDE
  /TITLES
    TITLE='SUPERFICIE SEMBRADA (ha) SEGÚN USO DE INSUMOS ORGÁNICOS O QUÏMICOS'  'Cultivos Transitorios'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 11. SUPERFICIE PLANTADA EN PASTOS CULTIVADOS POR TIPO DE PASTO Y SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS

*** ABRIR BASE DE PASTOS CULTIVADOS (pcnac2018.sav) ***.

DATASET ACTIVATE pastos.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

RECODE rc_clacul (767 = 1) (754 = 2) (763 = 3) (752 = 4) (766 = 5) (ELSE = 6) INTO Pastos_11.
VALUE LABELS Pastos_11 1'Saboya' 2'Gramalote' 3'Pasto miel (chilena)' 4'Brachiaria' 5'Raygras' 6'Otros pastos cultivados'.

FILTER BY pastos_cultiv.

WEIGHT BY fact_exp_fin.

***** TABLA 11. SUPERFICIE PLANTADA EN PASTOS CULTIVADOS POR TIPO DE PASTO Y SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS.

CTABLES
  /VLABELS VARIABLES=Pastos_11 ORG pc_k409ha QUI DISPLAY=LABEL
  /TABLE Pastos_11 [C] BY ORG [C] > pc_k409ha [S][SUM] + QUI [C] > pc_k409ha [S][SUM]
  /CATEGORIES VARIABLES=Pastos_11 EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=ORG [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=QUI [1] EMPTY=INCLUDE
  /TITLES
    TITLE='SUPERFICIE PLANTADA (ha) EN PASTOS CULTIVADOS POR TIPO DE PASTO Y SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS'
    'Pastos Cultivados'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

*** GUARDAR BASE DE PASTOS CULTIVADOS (pcnac2018.sav) ***.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 12. SUPERFICIE PLANTADA EN CULTIVOS PERMANENTES POR CULTIVO Y SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS.

*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav) ***.

DATASET ACTIVATE permanentes.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

RECODE rc_clacul (407 = 1) (411 = 2) (419 = 3) (456 = 4) (ELSE = 5) INTO Permanentes_12.
VALUE LABELS Permanentes_12 1'Banano (fruta fresca)' 2'Cacao (almendra seca)' 3'Caña de azúcar para azúcar' 4'Palma africana (fruta fresca)' 5'Otros permanentes'.

FILTER BY cultiv_perm.

WEIGHT BY fact_exp_fin.

***** TABLA 12. SUPERFICIE PLANTADA EN CULTIVOS PERMANENTES POR CULTIVO Y SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS.

CTABLES
  /VLABELS VARIABLES=Permanentes_12 ORG cp_k409ha QUI DISPLAY=LABEL
  /TABLE Permanentes_12 [C] BY ORG [C] > cp_k409ha [S][SUM] + QUI [C] > cp_k409ha [S][SUM]
  /CATEGORIES VARIABLES=Permanentes_12 EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=ORG [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=QUI [1] EMPTY=INCLUDE
  /TITLES
    TITLE='SUPERFICIE PLANTADA (ha) EN CULTIVOS PERMANENTES POR CULTIVO Y SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS'
    'Cultivos Permanentes'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

*** GUARDAR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav) ***.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 13. SUPERFICIE SEMBRADA EN CULTIVOS TRANSITORIOS POR CULTIVO Y SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS.

*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

DATASET ACTIVATE transitorios.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

RECODE ct_clacul (507 = 1) (548 = 2) (561 = 3) (573 = 4) (ELSE = 5) INTO Transitorios_13.
VALUE LABELS Transitorios_13 1'Arroz (en cáscara)' 2'Maíz duro seco (grano seco)' 3'Papa (tubérculo fresco)' 4'Soya' 5'Otros transitorios'.

FILTER BY cultiv_tran.

WEIGHT BY fact_exp_fin.

***** TABLA 13. SUPERFICIE SEMBRADA EN CULTIVOS TRANSITORIOS POR CULTIVO Y SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS.

CTABLES
  /VLABELS VARIABLES=Transitorios_13 ORG ct_k510h QUI DISPLAY=LABEL
  /TABLE Transitorios_13 [C] BY ORG [C] > ct_k510h [S][SUM] + QUI [C] > ct_k510h [S][SUM]
  /CATEGORIES VARIABLES=Transitorios_13 EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=ORG [1] EMPTY=INCLUDE
  /CATEGORIES VARIABLES=QUI [1] EMPTY=INCLUDE
  /TITLES
    TITLE='SUPERFICIE SEMBRADA (ha) EN CULTIVOS TRANSITORIOS POR CULTIVO Y SEGÚN USO DE INSUMOS ORGÁNICOS O QUÍMICOS'
    'Cultivos Transitorios'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

*** GUARDAR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* SECCIÓN II. EXTENSIÓN AGRARIA.
* ABRIR BASE DEL MÓDULO AMBIENTAL (ambnac2018.sav) ***.

DATASET NAME ambientales.

DATASET CLOSE permanentes.
DATASET CLOSE pastos.
DATASET CLOSE transitorios.

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

***** TABLA 14. PRODUCTORES AGROPECUARIOS POR TIPO DE FINANCIAMIENTO PRIMARIO RECIBIDO PARA SUS ACTIVIDADES PRODUCTIVAS.

CTABLES
  /VLABELS VARIABLES=ea_tipofinan_a1 DISPLAY=LABEL
  /TABLE ea_tipofinan_a1 [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=ea_tipofinan_a1 ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='PRODUCTORES AGROPECUARIOS POR TIPO DE FINANCIAMIENTO PRIMARIO RECIBIDO PARA SUS ACTIVIDADES PRODUCTIVAS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 15. PRODUCTORES AGROPECUARIOS POR TIPO DE FINANCIAMIENTO SECUNDARIO RECIBIDO PARA SUS ACTIVIDADES PRODUCTIVAS.

VALUE LABELS ea_tipofinan_a2 0'Sin financiamiento secundario'
1'Propio'
2'Banca privada'
3'Cooperativas y Cajas de ahorro'
4'Banca pública'
5'Prestamista informal'
6'Fundaciones u ONG'.

CTABLES
  /VLABELS VARIABLES=ea_tipofinan_a2 DISPLAY=LABEL
  /TABLE ea_tipofinan_a2 [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=ea_tipofinan_a2 ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='PRODUCTORES AGROPECUARIOS POR TIPO DE FINANCIAMIENTO SECUNDARIO RECIBIDO PARA SUS ACTIVIDADES PRODUCTIVAS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 16. PRODUCTORES AGROPECUARIOS QUE HAN RECIBIDO CAPACITACIÓN PARA SUS ACTIVIDADES PRODUCTIVAS.

CTABLES
  /VLABELS VARIABLES=ea_recibiocapa DISPLAY=LABEL
  /TABLE ea_recibiocapa [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=ea_recibiocapa ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='PRODUCTORES AGROPECUARIOS QUE HAN RECIBIDO CAPACITACIÓN PARA SUS ACTIVIDADES PRODUCTIVAS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 17. PRODUCTORES AGROPECUARIOS QUE HAN RECIBIDO ASISTENCIA TÉCNICA PARA SUS ACTIVIDADES PRODUCTIVAS.

CTABLES
  /VLABELS VARIABLES=ea_asistec DISPLAY=LABEL
  /TABLE ea_asistec [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=ea_asistec ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='PRODUCTORES AGROPECUARIOS QUE HAN RECIBIDO ASISTENCIA TÉCNICA PARA SUS ACTIVIDADES PRODUCTIVAS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 18. PRODUCTORES AGROPECUARIOS QUE HAN COMPRADO GANADO VACUNO IMPORTADO POR EL ESTADO.

RECODE ea_compganado (1 = 1) (ELSE = 2) INTO ea_compganado_R.
VALUE LABELS ea_compganado_R 1'SI' 2'NO'.

CTABLES
  /VLABELS VARIABLES=ea_compganado_R DISPLAY=LABEL
  /TABLE ea_compganado_R [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=ea_compganado_R ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='PRODUCTORES AGROPECUARIOS QUE HAN COMPRADO GANADO VACUNO IMPORTADO POR EL ESTADO'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

DELETE VARIABLES ea_compganado_R.


***** TABLA 19. PRODUCTORES AGROPECUARIOS QUE PERTENECEN A ALGUNA ASOCIACIÓN, COOPERATIVA Y/O COMITÉ DE PRODUCTORES AGROPECUARIOS.

RECODE ea_tiporgper (1 THRU 5 = 1) (ELSE = 2) INTO ea_tiporgper_R.
VALUE LABELS ea_tiporgper_R 1'SI' 2'NO'.

CTABLES
  /VLABELS VARIABLES=ea_tiporgper_R DISPLAY=LABEL
  /TABLE ea_tiporgper_R [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=ea_tiporgper_R ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='PRODUCTORES AGROPECUARIOS QUE PERTENECEN A ALGUNA ASOCIACIÓN, COOPERATIVA Y/O COMITÉ DE PRODUCTORES AGROPECUARIOS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 20. TIPO DE ORGANIZACIÓN A LA QUE PERTENECEN LOS PRODUCTORES AGROPECUARIOS.

CTABLES
  /VLABELS VARIABLES=ea_tiporgper DISPLAY=LABEL
  /TABLE ea_tiporgper [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=ea_tiporgper ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='TIPO DE ORGANIZACIÓN A LA QUE PERTENECEN LOS PRODUCTORES AGROPECUARIOS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2018'.


***** TABLA 21. DISTRIBUCIÓN DE LOS TIPOS DE ORGANIZACIÓN A LA QUE PERTENECEN LOS PRODUCTORES AGROPECUARIOS,
*****************   SEGÚN ACTIVIDAD PRINCIPAL DE LA ORGANIZACIÓN.

CTABLES
  /VLABELS VARIABLES=ea_tiporgper ea_priactorg DISPLAY=LABEL
  /TABLE ea_tiporgper [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] BY ea_priactorg [C]
  /CATEGORIES VARIABLES=ea_tiporgper [1, 2, 3, 4, 5] EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=ea_priactorg ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='DISTRIBUCIÓN DE LOS TIPOS DE ORGANIZACIÓN A LA QUE PERTENECEN LOS PRODUCTORES AGROPECUARIOS, SEGÚN ACTIVIDAD PRINCIPAL DE LA ORGANIZACIÓN'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2018'.

*--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* SECCIÓN III. BUENAS PRÁCTICAS AGROPECUARIAS.
* ABRIR BASE DEL MÓDULO AMBIENTAL (ambnac2018.sav) ***.

DATASET ACTIVATE ambientales.

***** TABLA 22. DISTRIBUCIÓN DE PERSONAS PRODUCTORAS POR TIEMPO DESDE EL ÚLTIMO ANÁLISIS DE SUELO.

CTABLES
  /VLABELS VARIABLES=plag_anasuelo DISPLAY=LABEL
  /TABLE plag_anasuelo [C][COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=plag_anasuelo [4, 1, 3, 2, OTHERNM] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='DISTRIBUCIÓN DE PERSONAS PRODUCTORAS POR TIEMPO DESDE EL ÚLTIMO ANÁLISIS DE SUELO'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 23. DISTRIBUCIÓN DE PERSONAS PRODUCTORAS POR NIVEL DE INSTRUCCIÓN Y SEGÚN TIEMPO DESDE EL ÚLTIMO ANÁLISIS DE SUELO.

* Recodificación del nivel de instrucción de la Persona Productora (PP).
RECODE cg_k102 (ELSE = COPY) INTO nivel_inst.
FREQUENCIES nivel_inst.
RECODE nivel_inst (7,9 = 1) (1,5 = 2) (2,6 = 3) (3 = 4) (4 = 5) (ELSE = COPY).
VARIABLE LABELS nivel_inst "Nivel de instrucción de la PP (recodificado)".
VALUE LABELS nivel_inst 1'Ninguna'
2'Primaria / Educación básica'
3'Secundaria / Educación Media'
4'Superior'
5'Posgrado'.

FREQUENCIES nivel_inst.

CTABLES
  /VLABELS VARIABLES=nivel_inst plag_anasuelo DISPLAY=LABEL
  /TABLE nivel_inst BY plag_anasuelo [COUNT F40.0, ROWPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=nivel_inst plag_anasuelo ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='DISTRIBUCIÓN DE PERSONAS PRODUCTORAS POR NIVEL DE INSTRUCCIÓN Y SEGÚN TIEMPO DESDE EL ÚLTIMO ANÁLISIS DE SUELO'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 24. DISTRIBUCIÓN DE PERSONAS PRODUCTORAS POR TIEMPO DESDE EL ÚLTIMO ANÁLISIS FOLIAR.

CTABLES
  /VLABELS VARIABLES=pa_uanafoliar DISPLAY=LABEL
  /TABLE pa_uanafoliar [C][COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=pa_uanafoliar [4, 1, 2, 3, OTHERNM] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='DISTRIBUCIÓN DE PERSONAS PRODUCTORAS POR TIEMPO DESDE EL ÚLTIMO ANÁLISIS FOLIAR'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 25. DISTRIBUCIÓN DE PERSONAS PRODUCTORAS POR NIVEL DE INSTRUCCIÓN Y SEGÚN TIEMPO DESDE EL ÚLTIMO ANÁLISIS FOLIAR.

CTABLES
  /VLABELS VARIABLES=nivel_inst pa_uanafoliar DISPLAY=LABEL
  /TABLE nivel_inst BY pa_uanafoliar [COUNT F40.0, ROWPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=nivel_inst pa_uanafoliar ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='DISTRIBUCIÓN DE PERSONAS PRODUCTORAS POR NIVEL DE INSTRUCCIÓN Y SEGÚN TIEMPO DESDE EL ÚLTIMO ANÁLISIS FOLIAR'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 26. PERSONAS PRODUCTORAS QUE APLICAN CONTROL DE PLAGAS, POR TIPO DE CONTROL DE PLAGAS.

/* Esta tabla ya no existe en el año 2018, pues las variables de cálculo han sido sustituidas por otras de temática diferente.


***** TABLA 27. PERSONAS PRODUCTORAS QUE UTILIZAN ELEMENTOS DE PROTECCIÓN AL APLICAR PLAGUICIDAS, POR TIPO DE ELEMENTO DE PROTECCIÓN.

CTABLES
  /VLABELS VARIABLES=plag_utilguan plag_utilmasca plag_utilgafas plag_utilcamisas plag_utilbotas plag_utilvesti DISPLAY=LABEL
  /TABLE BY plag_utilguan [COUNT F40.0, ROWPCT.COUNT PCT40.1] + plag_utilmasca [COUNT F40.0, ROWPCT.COUNT PCT40.1]
    + plag_utilgafas [COUNT F40.0, ROWPCT.COUNT PCT40.1] + plag_utilcamisas [COUNT F40.0, ROWPCT.COUNT PCT40.1] + 
    plag_utilbotas [COUNT F40.0, ROWPCT.COUNT PCT40.1] + plag_utilvesti [COUNT F40.0, ROWPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=plag_utilguan plag_utilmasca plag_utilgafas plag_utilcamisas plag_utilbotas 
    plag_utilvesti [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='PERSONAS PRODUCTORAS QUE UTILIZAN ELEMENTOS DE PROTECCIÓN AL APLICAR PLAGUICIDAS, POR TIPO DE ELEMENTO DE PROTECCIÓN'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 28. PERSONAS PRODUCTORAS QUE UTILIZAN FACILIDADES LOGÍSTICAS Y/O TECNOLÓGICAS, POR TIPO DE FACILIDAD.

CTABLES
  /VLABELS VARIABLES=pa_arealm pa_areempa pa_cfrio pa_cercaelect DISPLAY=LABEL
  /TABLE BY pa_arealm [COUNT F40.0, ROWPCT.COUNT PCT40.1] + pa_areempa [COUNT F40.0, ROWPCT.COUNT PCT40.1] + 
                    pa_cfrio [COUNT F40.0, ROWPCT.COUNT PCT40.1] + pa_cercaelect [COUNT F40.0, ROWPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=pa_arealm pa_areempa pa_cfrio pa_cercaelect ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='PERSONAS PRODUCTORAS QUE UTILIZAN FACILIDADES LOGÍSTICAS Y/O TECNOLÓGICAS, POR TIPO DE FACILIDAD'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 29. PERSONAS PRODUCTORAS QUE REALIZAN ACTIVIDADES DE POST COSECHA, POR TIPO DE ACTIVIDAD.

CTABLES
  /VLABELS VARIABLES=pa_pcselec pa_pclavado pa_pcempaque DISPLAY=LABEL
  /TABLE BY pa_pcselec [COUNT F40.0, ROWPCT.COUNT PCT40.1] + pa_pclavado [COUNT F40.0, ROWPCT.COUNT PCT40.1] + 
                    pa_pcempaque [COUNT F40.0, ROWPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=pa_pcselec pa_pclavado pa_pcempaque ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='PERSONAS PRODUCTORAS QUE REALIZAN ACTIVIDADES DE POST COSECHA, POR TIPO DE ACTIVIDAD'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 30. PRODUCTORES AGROPECUARIOS QUE TIENEN CONOCIMIENTOS SOBRE INOCUIDAD DE ALIMENTOS.

CTABLES
  /VLABELS VARIABLES=pa_inocuidad DISPLAY=LABEL
  /TABLE pa_inocuidad [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=pa_inocuidad ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='PRODUCTORES AGROPECUARIOS QUE TIENEN CONOCIMIENTOS SOBRE INOCUIDAD DE ALIMENTOS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


**************************************************************************************************************************************************************************************
*------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* SECCIÓN IV. EQUIPAMIENTO.

*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

DATASET NAME transitorios.

FILTER OFF.
USE ALL.
WEIGHT OFF.

SORT CASES BY ct_prov ct_cant ct_estr ct_segm ct_ncues.

STRING identif (A17).
COMPUTE identif = CONCAT(LTRIM(RTRIM(ct_prov)), LTRIM(RTRIM(ct_cant)), LTRIM(RTRIM(ct_estr)), LTRIM(RTRIM(ct_segm)), LTRIM(RTRIM(ct_ncues))).
EXECUTE.

SORT CASES BY identif(A).
MATCH FILES
  /FILE=*
  /BY identif
  /FIRST=PP_Transitorios.
VARIABLE LABELS PP_Transitorios "Personas productoras de cultivos transitorios".
VARIABLE LEVEL  PP_Transitorios (ORDINAL).
FREQUENCIES PP_Transitorios.
EXECUTE.

* ABRIR BASE DEL MÓDULO AMBIENTAL (ambnac2018.sav) ***.

DATASET ACTIVATE ambientales.

* Llevar la variable PP_Transitorios de la base de cultivos transitorios a la base del módulo ambiental.

SORT CASES BY identif(A).

DATASET ACTIVATE ambientales.
MATCH FILES /FILE=*
  /FILE='transitorios'
  /RENAME (su_fertilizada su_plaguicidas ct_secertificada ct_clacul ct_nclavr ct_secomun 
    ct_nuevacondicion ct_k511h ct_afecta_prod ct_cant ct_cant1_fo ct_cant2_fo ct_cant3_fo 
    ct_cantidad_fq ct_cantidad_fun_pq ct_cantidad_her_pq ct_cantidad_ins_pq ct_cantidad_nit_fq 
    ct_cantidad_npk_fq ct_cantidad_po ct_cantidad_pot_fq ct_cantidad_pq ct_codcultiv1_int 
    ct_codcultiv2_int ct_color_fun_pq ct_color_her_pq ct_color_ins_pq ct_color_pq ct_condcult_int 
    ct_estr ct_fconvf ct_fconvs ct_forg ct_fqui ct_k504 ct_k505 ct_k506 ct_k506_R ct_k506r ct_k507 
    ct_k508 ct_k509 ct_k512 ct_k513 ct_k514 ct_k515 ct_k516 ct_k517 ct_k518 ct_k520 ct_k522 ct_k523 
    ct_k524 ct_k526 ct_kits_agri ct_messiem_int ct_ncues ct_numl ct_numt ct_piensasem_int ct_porc_aspe 
    ct_porc_gote ct_porc_micr ct_porc_nebu ct_porc_otro ct_porc_surc ct_porg ct_pqui ct_prepa_suelo 
    ct_presueuti ct_rdproven1 ct_rdproven2 ct_rdproven3 ct_rdproven4 ct_rdproven5 ct_rdproven6 ct_riego 
    ct_seg_agri ct_segm ct_superf_regada_ha ct_supersemha_int ct_umed1_fo ct_umed2_fo ct_umed3_fo 
    ct_umed_fq ct_umed_fun_pq ct_umed_her_pq ct_umed_ins_pq ct_umed_nit_fq ct_umed_npk_fq ct_umed_po 
    ct_umed_pot_fq ct_umed_pq cultiv_tran ct_enfermedades fact_exp_fin ct_helada ct_sehibrinter 
    ct_sehibrinac Identificador ct_inundacion ct_semejorada NIN ct_otra ct_plagas ct_prod ct_prov 
    ct_k512r ct_tro ct_trc ct_trs ct_sriego ct_k510h ct_sequia ct_superdida ct_tn Transitorios_13 ORG 
    TOD QUI Ventas ct_tznd = d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 
    d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 
    d46 d47 d48 d49 d50 d51 d52 d53 d54 d55 d56 d57 d58 d59 d60 d61 d62 d63 d64 d65 d66 d67 d68 d69 d70 
    d71 d72 d73 d74 d75 d76 d77 d78 d79 d80 d81 d82 d83 d84 d85 d86 d87 d88 d89 d90 d91 d92 d93 d94 d95 
    d96 d97 d98 d99 d100 d101 d102 d103 d104 d105 d106 d107 d108 d109 d110 d111 d112 d113 d114 d115 
    d116 d117 d118 d119 d120 d121) 
  /BY identif
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 
    d50 d51 d52 d53 d54 d55 d56 d57 d58 d59 d60 d61 d62 d63 d64 d65 d66 d67 d68 d69 d70 d71 d72 d73 d74 
    d75 d76 d77 d78 d79 d80 d81 d82 d83 d84 d85 d86 d87 d88 d89 d90 d91 d92 d93 d94 d95 d96 d97 d98 d99 
    d100 d101 d102 d103 d104 d105 d106 d107 d108 d109 d110 d111 d112 d113 d114 d115 d116 d117 d118 d119 
    d120 d121.
EXECUTE.

FILTER OFF.
USE ALL.
SELECT IF  (NOT(ORIGINAL=0)).
EXECUTE.

* Guardar base del módulo ambiental.

* Cerrar la base de cultivos transitorios.

DATASET CLOSE transitorios.

* Cálculo de los Productores Agropecuarios que utilizan máquinas para desarrollar sus actividades productivas

RECODE eq_etractor (0 = SYSMIS) (ELSE = COPY) INTO eq_etractor_R.
RECODE eq_emotocultor (0 = SYSMIS) (ELSE = COPY) INTO eq_emotocultor_R.
RECODE eq_eyunta (0 = SYSMIS) (ELSE = COPY) INTO eq_eyunta_R.

RECODE eq_earado (0 = SYSMIS) (ELSE = COPY) INTO eq_earado_R.
RECODE eq_erastra (0 = SYSMIS) (ELSE = COPY) INTO eq_erastra_R.
RECODE eq_esurcadora (0 = SYSMIS) (ELSE = COPY) INTO eq_esurcadora_R.
RECODE eq_efangueo (0 = SYSMIS) (ELSE = COPY) INTO eq_efangueo_R.

COMPUTE No_13_1 = MIN(eq_etractor_R, eq_emotocultor_R, eq_eyunta_R). /* PA que responden SI en todas las variables de tipo SI/NO de la etapa 13.1.

COMPUTE No_13_1_1 = MIN(eq_earado_R, eq_erastra_R, eq_esurcadora_R, eq_efangueo_R). /* PA que responden SI en todas las variables de tipo SI/NO de la etapa 13.1.1.

COMPUTE No_13_2 = MIN(eq_semman, eq_semmec, eq_splanman, eq_splanmec).  /* PA que responden SI en todas las variables de tipo SI/NO de la etapa 13.2.

COMPUTE No_13_3 = MIN(eq_eboleadora, eq_emotoguadana, eq_ecultivador, eq_eaguilon, eq_ebestaciona, eq_ebmotor, eq_ebmanual). /* PA que responden SI
/* en todas las variables de tipo SI/NO de la etapa 13.3.

COMPUTE No_13_4 = MIN(eq_etricombi, eq_etrilladora, eq_ecosgranfigr, eq_esegadora, eq_ecosotras). /* PA que responden SI en todas las variables de tipo SI/NO
/*  de la etapa 13.4.

COMPUTE No_13 = MIN(No_13_1, No_13_1_1, No_13_2, No_13_3, No_13_4).  /* PA que responden SI en todas las variables de tipo SI/NO de la
/*  Pregunta 13. EQUIPAMIENTO.
FREQUENCIES No_13.

VARIABLE LABELS No_13 "Productores Agropecuarios que utilizan máquinas para desarrollar sus actividades productivas".
VALUE LABELS No_13 2'No utilizan máquinas' 1'Sí utilizan máquinas'.
FREQUENCIES No_13.

***** TABLA 31. PRODUCTORES AGROPECUARIOS QUE UTILIZARON MÁQUINAS PARA DESARROLLAR SUS ACTIVIDADES PRODUCTIVAS.

FILTER BY PP_Transitorios.

* Tablas personalizadas.
CTABLES
  /VLABELS VARIABLES=No_13 DISPLAY=LABEL
  /TABLE No_13 [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=No_13 ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='PRODUCTORES AGROPECUARIOS CON CULTIVOS TRANSITORIOS QUE UTILIZARON MÁQUINAS PARA DESARROLLAR SUS ACTIVIDADES PRODUCTIVAS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


****************************************************************************************************************************************************************************************************

* TABLA 32. PRODUCTORES AGROPECUARIOS QUE UTILIZARON EQUIPO PARA PREPARAR EL TERRENO DE CULTIVO, POR TIPO DE EQUIPO USADO
* Y SEGÚN PROPIEDAD DEL EQUIPO.

DATASET ACTIVATE Conjunto_de_datos1.
USE ALL.
COMPUTE filter_$=(flitro_4 >= 1).
VARIABLE LABELS filter_$ 'flitro_4 >= 1 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

** TABLA 30. PRODUCTORES AGROPECUARIOS QUE UTILIZARON EQUIPO PARA PREPARAR EL SUELO PARA CULTIVO*** 

FREQUENCIES VARIABLES=eq_etractor_1 eq_emotocultor_1 eq_yunta_1
  /ORDER=ANALYSIS.

***TABLA 31. PRODUCTORES AGROPECUARIOS QUE UTILIZARON EQUIPO PARA LA LABOR DEL TERRENO DE CULTIVO***

FREQUENCIES VARIABLES=eq_earado eq_tearado eq_erastra eq_terastra eq_esurcadora eq_tesurcadora eq_efangueo eq_tefangueo
  /ORDER=ANALYSIS.


***TABLA 32. PRODUCTORES AGROPECUARIOS QUE UTILIZARON EQUIPO PARA SEMBRAR EL TERRENO DE CULTIVO***

FREQUENCIES VARIABLES=eq_semman eq_tsemman eq_semmec eq_tsemmec eq_splanman eq_tsplanman eq_splanmec eq_tsplanmec eq_sninguna
  /ORDER=ANALYSIS.

***TABLA 33. PRODUCTORES AGROPECUARIOS QUE UTILIZARON EQUIPO PARA DESARROLLO DE SUS CULTIVOS***

FREQUENCIES VARIABLES=eq_eboleadora eq_teboleadora eq_emotoguadana eq_tmotoguadana eq_ecultivador eq_tecultivador eq_eaguilon eq_teaguilon eq_ebestaciona eq_tebestaciona eq_ebmotor eq_tebmotor eq_ebmanual eq_tebmanual eq_dninguno
  /ORDER=ANALYSIS.

**TABLA 34. PRODUCTORES AGROPECUARIOS QUE UTILIZARON EQUIPO PARA COSECHAR SUS CULTIVOS, POR TIPO DE EQUIPO USADO Y SEGÚN PROPIEDAD DEL EQUIPO***															

FREQUENCIES VARIABLES=eq_etricombi eq_tetricombi eq_etrilladora eq_tetrilladora eq_ecosgranfigr eq_tecosgranfigr eq_esegadora eq_tesegadora eq_ecosotras eq_tecosotras eq_cninguno
  /ORDER=ANALYSIS.


*** GUARDAR BASE DEL MÓDULO AMBIENTAL (ambnac2018.sav) ***.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* SECCIÓN V. AGUA.

* TABLA 37. SUPERFICIE AGROPECUARIA BAJO RIEGO, SEGÚN TIPO DE CULTIVO

* TABLA 37.1 PARA CULTIVOS PERMANENTES ÚNICAMENTE.
*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav) ***.

DATASET NAME permanentes.

DATASET CLOSE ambientales.

WEIGHT OFF.
FILTER OFF.
USE ALL.

COMPUTE cultiv_perm_riego = (cultiv_perm = 1 & cp_riego = 1). /* Filtra cultivos permanentes con alguna clase de riego.
FREQUENCIES cultiv_perm_riego.

FILTER BY cultiv_perm.

WEIGHT BY fact_exp_fin.

***** TABLA 37.1 SUPERFICIE AGROPECUARIA BAJO RIEGO EN CULTIVOS PERMANENTES.

CTABLES
  /VLABELS VARIABLES=cp_riego cp_k409ha DISPLAY=LABEL
  /TABLE cp_riego BY cp_k409ha [SUM, COLPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=cp_riego ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
 /TITLES
    TITLE='SUPERFICIE AGROPECUARIA BAJO RIEGO EN CULTIVOS PERMANENTES'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

WEIGHT OFF.
FILTER OFF.
USE ALL.


* TABLA 37.2 PARA CULTIVOS TRANSITORIOS ÚNICAMENTE.
*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

DATASET NAME transitorios.

WEIGHT OFF.
FILTER OFF.
USE ALL.

COMPUTE cultiv_tran_riego = (cultiv_tran = 1 & ct_riego = 1). /* Filtra cultivos transitorios con alguna clase de riego.
FREQUENCIES cultiv_tran_riego.

FILTER BY cultiv_tran.

WEIGHT BY fact_exp_fin.

***** TABLA 37.2 SUPERFICIE AGROPECUARIA BAJO RIEGO EN CULTIVOS TRANSITORIOS.

CTABLES
  /VLABELS VARIABLES=ct_riego ct_k510h DISPLAY=LABEL
  /TABLE ct_riego BY ct_k510h [SUM, COLPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=ct_riego ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
 /TITLES
    TITLE='SUPERFICIE AGROPECUARIA BAJO RIEGO EN CULTIVOS TRANSITORIOS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

WEIGHT OFF.
FILTER OFF.
USE ALL.


* TABLA 37.3 SUPERFICIE AGROPECUARIA BAJO RIEGO EN PASTOS CULTIVADOS.
*** ABRIR BASE DE PASTOS CULTIVADOS (pcnac2018.sav) ***.

DATASET NAME pastos.

WEIGHT OFF.
FILTER OFF.
USE ALL.

COMPUTE pastos_cultiv_riego = (pastos_cultiv = 1 & cp_riego = 1). /* Filtra pastos cultivados con alguna clase de riego.

WEIGHT BY fact_exp_fin.

***** TABLA 37.3 SUPERFICIE AGROPECUARIA BAJO RIEGO EN PASTOS CULTIVADOS.

CTABLES
  /VLABELS VARIABLES=cp_riego pc_k409ha DISPLAY=LABEL
  /TABLE cp_riego BY pc_k409ha [SUM, COLPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=cp_riego ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
 /TITLES
    TITLE='SUPERFICIE AGROPECUARIA BAJO RIEGO EN PASTOS CULTIVADOS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

WEIGHT OFF.
FILTER OFF.
USE ALL.


* TABLA 37.4 SUPERFICIE AGROPECUARIA BAJO RIEGO EN FLORES PERMANENTES.
*** ABRIR BASE DE FLORES PERMANENTES (fpnac2018.sav) ***.

DATASET NAME flores_perm.

WEIGHT OFF.
FILTER OFF.
USE ALL.

COMPUTE flores_perm_riego = (fp_riego = 1). /* Filtra flores permanentes con alguna clase de riego.
FREQUENCIES flores_perm_riego.

WEIGHT BY fact_exp_fin.

***** TABLA 37.4 SUPERFICIE AGROPECUARIA BAJO RIEGO EN FLORES PERMANENTES.

CTABLES
  /VLABELS VARIABLES=fp_riego fp_k706h DISPLAY=LABEL
  /TABLE fp_riego BY fp_k706h [SUM, COLPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=fp_riego ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
 /TITLES
    TITLE='SUPERFICIE AGROPECUARIA BAJO RIEGO EN FLORES PERMANENTES'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

WEIGHT OFF.
FILTER OFF.
USE ALL.


* TABLA 37.5 SUPERFICIE AGROPECUARIA BAJO RIEGO EN FLORES TRANSITORIAS.
*** ABRIR BASE DE FLORES TRANSITORIAS (ftnac2018.sav) ***.

DATASET NAME flores_tran.

WEIGHT OFF.
FILTER OFF.
USE ALL.

COMPUTE flores_tran_riego = (ft_riego = 1). /* Filtra flores transitorias con alguna clase de riego.
FREQUENCIES flores_tran_riego.

WEIGHT BY fact_exp_fin.

***** TABLA 37.5 SUPERFICIE AGROPECUARIA BAJO RIEGO EN FLORES TRANSITORIAS.

CTABLES
  /VLABELS VARIABLES=ft_riego ft_k720h DISPLAY=LABEL
  /TABLE ft_riego BY ft_k720h [SUM, COLPCT.SUM PCT40.1]
  /CATEGORIES VARIABLES=ft_riego ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
 /TITLES
    TITLE='SUPERFICIE AGROPECUARIA BAJO RIEGO EN FLORES TRANSITORIAS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

WEIGHT OFF.
FILTER OFF.
USE ALL.


*------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 38. SUPERFICIE BAJO RIEGO, POR MÉTODO DE RIEGO Y SEGÚN TIPO DE CULTIVO.

* TABLA 38.1 SUPERFICIE BAJO RIEGO, POR MÉTODO DE RIEGO EN CULTIVOS PERMANENTES.

*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav) ***.

DATASET ACTIVATE permanentes.

FILTER OFF.
USE ALL.
WEIGHT OFF.

COMPUTE sup_riego_surc = cp_porc_surc * cp_k409ha / 100. /* Superficie de cultivos permanentes regada por surcos-inundación.
COMPUTE sup_riego_aspe = cp_porc_aspe * cp_k409ha / 100.  /* Superficie de cultivos permanentes regada por aspersión.
COMPUTE sup_riego_micr = cp_porc_micr * cp_k409ha / 100.  /* Superficie de cultivos permanentes regada por microaspersión.
COMPUTE sup_riego_gote = cp_porc_gote * cp_k409ha / 100.  /* Superficie de cultivos permanentes regada por goteo.
COMPUTE sup_riego_nebu = cp_porc_nebu * cp_k409ha / 100. /* Superficie de cultivos permanentes regada por nebulización.
COMPUTE sup_riego_otro = cp_porc_otro * cp_k409ha / 100.  /* Superficie de cultivos permanentes regada por otra tecnología.
EXECUTE.

WEIGHT BY fact_exp_fin. /* Toda superficie debe expandirse con este factor de expansión.

FILTER BY cultiv_perm_riego.

***** TABLA 38.1 SUPERFICIE BAJO RIEGO, POR MÉTODO DE RIEGO EN CULTIVOS PERMANENTES.

CTABLES
  /VLABELS VARIABLES=sup_riego_surc sup_riego_aspe sup_riego_micr sup_riego_gote sup_riego_nebu sup_riego_otro cp_riego 
    DISPLAY=LABEL
  /TABLE sup_riego_surc [SUM] + sup_riego_aspe [SUM] + sup_riego_micr [SUM] + sup_riego_gote [SUM] + sup_riego_nebu [SUM] + sup_riego_otro [SUM] BY cp_riego
  /CATEGORIES VARIABLES=cp_riego [1] EMPTY=INCLUDE
 /TITLES
    TITLE='SUPERFICIE AGROPECUARIA BAJO RIEGO, POR MÉTODO DE RIEGO EN CULTIVOS PERMANENTES'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


* TABLA 38.2 SUPERFICIE BAJO RIEGO, POR MÉTODO DE RIEGO EN CULTIVOS TRANSITORIOS.

*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

DATASET ACTIVATE transitorios.

FILTER OFF.
USE ALL.
WEIGHT OFF.

COMPUTE sup_riego_surc = ct_porc_surc * ct_k510h / 100. /* Superficie de cultivos transitorios regada por surcos-inundación.
COMPUTE sup_riego_aspe = ct_porc_aspe * ct_k510h / 100.  /* Superficie de cultivos transitorios regada por aspersión.
COMPUTE sup_riego_micr = ct_porc_micr * ct_k510h / 100.  /* Superficie de cultivos transitorios regada por microaspersión.
COMPUTE sup_riego_gote = ct_porc_gote * ct_k510h / 100.  /* Superficie de cultivos transitorios regada por goteo.
COMPUTE sup_riego_nebu = ct_porc_nebu * ct_k510h / 100. /* Superficie de cultivos transitorios regada por nebulización.
COMPUTE sup_riego_otro = ct_porc_otro * ct_k510h / 100.  /* Superficie de cultivos transitorios regada por otra tecnología.
EXECUTE.

WEIGHT BY fact_exp_fin. /* Toda superficie debe expandirse con este factor de expansión.

FILTER BY cultiv_tran_riego.

***** TABLA 36.2 SUPERFICIE BAJO RIEGO, POR MÉTODO DE RIEGO EN CULTIVOS TRANSITORIOS.

CTABLES
  /VLABELS VARIABLES=sup_riego_surc sup_riego_aspe sup_riego_micr sup_riego_gote sup_riego_nebu sup_riego_otro ct_riego 
    DISPLAY=LABEL
  /TABLE sup_riego_surc [SUM] + sup_riego_aspe [SUM] + sup_riego_micr [SUM] + sup_riego_gote [SUM] + sup_riego_nebu [SUM] + sup_riego_otro [SUM] BY ct_riego
  /CATEGORIES VARIABLES=ct_riego [1] EMPTY=INCLUDE
 /TITLES
    TITLE='SUPERFICIE AGROPECUARIA BAJO RIEGO, POR MÉTODO DE RIEGO EN CULTIVOS TRANSITORIOS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

FILTER OFF.
USE ALL.
WEIGHT OFF.


* TABLA 38.3 SUPERFICIE BAJO RIEGO, POR MÉTODO DE RIEGO EN PASTOS CULTIVADOS.

*** ABRIR BASE DE PASTOS CULTIVADOS (pcnac2018.sav) ***.

DATASET ACTIVATE pastos.

FILTER OFF.
USE ALL.
WEIGHT OFF.

COMPUTE sup_riego_surc = cp_porc_surc * pc_k409ha / 100. /* Superficie de pastos cultivados regada por surcos-inundación.
COMPUTE sup_riego_aspe = cp_porc_aspe * pc_k409ha / 100.  /* Superficie de pastos cultivados regada por aspersión.
COMPUTE sup_riego_micr = cp_porc_micr * pc_k409ha / 100.  /* Superficie de pastos cultivados regada por microaspersión.
COMPUTE sup_riego_gote = cp_porc_gote * pc_k409ha / 100.  /* Superficie de pastos cultivados regada por goteo.
COMPUTE sup_riego_nebu = cp_porc_nebu * pc_k409ha / 100. /* Superficie de pastos cultivados regada por nebulización.
COMPUTE sup_riego_otro = cp_porc_otro * pc_k409ha / 100.  /* Superficie de pastos cultivados regada por otra tecnología.
EXECUTE.

WEIGHT BY fact_exp_fin. /* Toda superficie debe expandirse con este factor de expansión.

***** TABLA 38.3 SUPERFICIE BAJO RIEGO, POR MÉTODO DE RIEGO EN PASTOS CULTIVADOS.

VARIABLE LEVEL sup_riego_nebu (SCALE).

SPLIT FILE BY cp_riego.

CTABLES
  /VLABELS VARIABLES=sup_riego_surc sup_riego_aspe sup_riego_micr sup_riego_gote sup_riego_nebu sup_riego_otro cp_riego 
    DISPLAY=LABEL
  /TABLE sup_riego_surc [SUM] + sup_riego_aspe [SUM] + sup_riego_micr [SUM] + sup_riego_gote [SUM] + sup_riego_nebu [SUM] + sup_riego_otro [SUM] BY cp_riego
  /CATEGORIES VARIABLES=cp_riego [1] EMPTY=INCLUDE
 /TITLES
    TITLE='SUPERFICIE AGROPECUARIA BAJO RIEGO, POR MÉTODO DE RIEGO EN PASTOS CULTIVADOS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

SPLIT FILE OFF.
WEIGHT OFF.


* TABLA 38.4 SUPERFICIE BAJO RIEGO, POR MÉTODO DE RIEGO EN FLORES PERMANENTES.

*** ABRIR BASE DE FLORES PERMANENTES (fpnac2018.sav) ***.

DATASET ACTIVATE flores_perm.

FILTER OFF.
USE ALL.
WEIGHT OFF.

COMPUTE sup_riego_surc = fp_porc_surc * fp_k706h / 100. /* Superficie de flores permanentes regada por surcos-inundación.
COMPUTE sup_riego_aspe = fp_porc_aspe * fp_k706h / 100.  /* Superficie de flores permanentes regada por aspersión.
COMPUTE sup_riego_micr = fp_porc_micr * fp_k706h / 100.  /* Superficie de flores permanentes regada por microaspersión.
COMPUTE sup_riego_gote = fp_porc_gote * fp_k706h / 100.  /* Superficie de flores permanentes regada por goteo.
COMPUTE sup_riego_nebu = fp_porc_nebu * fp_k706h / 100. /* Superficie de flores permanentes regada por nebulización.
COMPUTE sup_riego_otro = fp_porc_otro * fp_k706h / 100.  /* Superficie de flores permanentes regada por otra tecnología.
EXECUTE.

WEIGHT BY fact_exp_fin. /* Toda superficie debe expandirse con este factor de expansión.

SPLIT FILE BY fp_riego.

***** TABLA 38.4 SUPERFICIE BAJO RIEGO, POR MÉTODO DE RIEGO EN FLORES PERMANENTES.

CTABLES
  /VLABELS VARIABLES=sup_riego_surc sup_riego_aspe sup_riego_micr sup_riego_gote sup_riego_nebu sup_riego_otro fp_riego 
    DISPLAY=LABEL
  /TABLE sup_riego_surc [SUM] + sup_riego_aspe [SUM] + sup_riego_micr [SUM] + sup_riego_gote [SUM] + sup_riego_nebu [SUM] + sup_riego_otro [SUM] BY fp_riego
  /CATEGORIES VARIABLES=fp_riego [1] EMPTY=INCLUDE
 /TITLES
    TITLE='SUPERFICIE AGROPECUARIA BAJO RIEGO, POR MÉTODO DE RIEGO EN FLORES PERMANENTES'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

SPLIT FILE OFF.
WEIGHT OFF.


* TABLA 38.5 SUPERFICIE BAJO RIEGO, POR MÉTODO DE RIEGO EN FLORES TRANSITORIAS.

*** ABRIR BASE DE FLORES TRANSITORIAS (ftnac2018.sav) ***.

DATASET ACTIVATE flores_tran.

FILTER OFF.
USE ALL.
WEIGHT OFF.

COMPUTE sup_riego_surc = ft_porc_surc * ft_k720h / 100. /* Superficie de flores transitorias regada por surcos-inundación.
COMPUTE sup_riego_aspe = ft_porc_aspe * ft_k720h / 100.  /* Superficie de flores transitorias regada por aspersión.
COMPUTE sup_riego_micr = ft_porc_micr * ft_k720h / 100.  /* Superficie de flores transitorias regada por microaspersión.
COMPUTE sup_riego_gote = ft_porc_gote * ft_k720h / 100.  /* Superficie de flores transitorias regada por goteo.
COMPUTE sup_riego_nebu = ft_porc_nebu * ft_k720h / 100. /* Superficie de flores transitorias regada por nebulización.
COMPUTE sup_riego_otro = ft_porc_otro * ft_k720h / 100.  /* Superficie de flores transitorias regada por otra tecnología.
EXECUTE.

WEIGHT BY fact_exp_fin. /* Toda superficie debe expandirse con este factor de expansión.

VARIABLE LEVEL sup_riego_surc (SCALE).
VARIABLE LEVEL sup_riego_nebu (SCALE).
VARIABLE LEVEL sup_riego_otro (SCALE).

SPLIT FILE BY ft_riego.

***** TABLA 38.5 SUPERFICIE BAJO RIEGO, POR MÉTODO DE RIEGO EN FLORES TRANSITORIAS.

CTABLES
  /VLABELS VARIABLES=sup_riego_surc sup_riego_aspe sup_riego_micr sup_riego_gote sup_riego_nebu sup_riego_otro ft_riego 
    DISPLAY=LABEL
  /TABLE sup_riego_surc [SUM] + sup_riego_aspe [SUM] + sup_riego_micr [SUM] + sup_riego_gote [SUM] + sup_riego_nebu [SUM] + sup_riego_otro [SUM] BY ft_riego
  /CATEGORIES VARIABLES=ft_riego [1] EMPTY=INCLUDE
 /TITLES
    TITLE='SUPERFICIE AGROPECUARIA BAJO RIEGO, POR MÉTODO DE RIEGO EN FLORES TRANSITORIAS'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

SPLIT FILE OFF.
WEIGHT OFF.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

*** GUARDAR BASES DE DATOS DE FLORES PERMANENTES (fpnac2018.sav) Y DE FLORES TRANSITORIAS (ftnac2018.sav).

DATASET ACTIVATE permanentes.
DATASET CLOSE flores_perm.
DATASET CLOSE flores_tran.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 39. SUPERFICIE BAJO RIEGO POR TIPO DE CULTIVO PERMANENTE Y SEGÚN MÉTODO DE RIEGO.

*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav) ***.

WEIGHT OFF.
FILTER OFF.
USE ALL.

FILTER BY cultiv_perm.
WEIGHT BY fact_exp_fin.

***** TABLA 39. SUPERFICIE BAJO RIEGO POR TIPO DE CULTIVO PERMANENTE Y SEGÚN MÉTODO DE RIEGO.

CTABLES
  /VLABELS VARIABLES=Permanentes_12 sup_riego_surc sup_riego_aspe sup_riego_micr sup_riego_gote sup_riego_nebu sup_riego_otro DISPLAY=LABEL
  /TABLE Permanentes_12 [C] BY sup_riego_surc [SUM] + sup_riego_aspe [SUM] + sup_riego_micr [SUM] + sup_riego_gote [SUM] + sup_riego_nebu [S][SUM] + sup_riego_otro [SUM]
  /CATEGORIES VARIABLES=Permanentes_12 ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='SUPERFICIE BAJO RIEGO, POR TIPO DE CULTIVO PERMANENTE Y SEGÚN MÉTODO DE RIEGO'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

FILTER OFF.
USE ALL.
WEIGHT OFF.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 40. SUPERFICIE BAJO RIEGO, POR TIPO DE CULTIVO TRANSITORIO Y SEGÚN MÉTODO DE RIEGO.

*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ***.

DATASET ACTIVATE transitorios.

WEIGHT OFF.
FILTER OFF.
USE ALL.

FILTER BY cultiv_tran.
WEIGHT BY fact_exp_fin.

***** TABLA 40. SUPERFICIE BAJO RIEGO, POR TIPO DE CULTIVO TRANSITORIO Y SEGÚN MÉTODO DE RIEGO.

CTABLES
  /VLABELS VARIABLES=Transitorios_13 sup_riego_surc sup_riego_aspe sup_riego_micr sup_riego_gote sup_riego_nebu sup_riego_otro DISPLAY=LABEL
  /TABLE Transitorios_13 [C] BY sup_riego_surc [SUM] + sup_riego_aspe [SUM] + sup_riego_micr [SUM] + sup_riego_gote [SUM] + sup_riego_nebu [S][SUM] + sup_riego_otro [SUM]
  /CATEGORIES VARIABLES=Transitorios_13 ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='SUPERFICIE BAJO RIEGO, POR TIPO DE CULTIVO TRANSITORIO Y SEGÚN MÉTODO DE RIEGO'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

FILTER OFF.
USE ALL.
WEIGHT OFF.

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* TABLA 41. SUPERFICIE BAJO RIEGO, POR TIPO DE PASTO CULTIVADO Y SEGÚN MÉTODO DE RIEGO.

*** ABRIR BASE DE PASTOS CULTIVADOS (pcnac2018.sav) ***.

DATASET ACTIVATE pastos.

WEIGHT OFF.
FILTER OFF.
USE ALL.

SPLIT FILE BY cp_riego.
WEIGHT BY fact_exp_fin.

***** TABLA 41. SUPERFICIE BAJO RIEGO POR TIPO DE PASTO CULTIVADO Y SEGÚN MÉTODO DE RIEGO.

CTABLES
  /VLABELS VARIABLES=Pastos_11 sup_riego_surc sup_riego_aspe sup_riego_micr sup_riego_gote sup_riego_nebu sup_riego_otro DISPLAY=LABEL
  /TABLE Pastos_11 [C] BY sup_riego_surc [SUM] + sup_riego_aspe [SUM] + sup_riego_micr [SUM] + sup_riego_gote [SUM] + sup_riego_nebu [S][SUM] + sup_riego_otro [SUM]
  /CATEGORIES VARIABLES=Pastos_11 ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='SUPERFICIE BAJO RIEGO, POR TIPO DE PASTO CULTIVADO Y SEGÚN MÉTODO DE RIEGO'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

SPLIT FILE OFF.
WEIGHT OFF.

*** GUARDAR BASE DE PASTOS CULTIVADOS (pcnac2018.sav) ***


*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

* ABRIR BASE DEL MÓDULO AMBIENTAL (ambnac2018.sav) ***.

DATASET NAME ambientales.

* CERRAR BASE DE PASTOS CULTIVADOS (pcnac2018.sav) ***

DATASET CLOSE pastos.

***** TABLA 42. DISTRIBUCIÓN DE AGUA DE RIEGO USADA POR LOS PRODUCTORES AGROPECUARIOS, POR TIPO DE FUENTE

CTABLES
  /VLABELS VARIABLES=ag_proviriego DISPLAY=LABEL
  /TABLE ag_proviriego [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=ag_proviriego ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='DISTRIBUCIÓN DE AGUA DE RIEGO USADA POR LOS PRODUCTORES AGROPECUARIOS, POR TIPO DE FUENTE'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 43. DISTRIBUCIÓN DE TIEMPO DESDE QUE LOS PRODUCTORES AGROPECUARIOS REALIZARON EL ÚLTIMO ANÁLISIS DE AGUA, POR PERÍODO DE TIEMPO.

CTABLES
  /VLABELS VARIABLES=ag_analagua DISPLAY=LABEL
  /TABLE ag_analagua [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=ag_analagua ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='DISTRIBUCIÓN DE TIEMPO DESDE QUE LOS PRODUCTORES AGROPECUARIOS REALIZARON EL ÚLTIMO ANÁLISIS DE AGUA, POR PERÍODO DE TIEMPO'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 44. DISTRIBUCIÓN DE TECNOLOGÍAS DE RIEGO QUE LOS PRODUCTORES AGROPECUARIOS USAN PARA SUS ACTIVIDADES, POR TIPO DE TECNOLOGÍA.

CTABLES
  /VLABELS VARIABLES=ag_rsfertirri ag_rbombas ag_rreservorio DISPLAY=LABEL
  /TABLE BY ag_rsfertirri [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] + ag_rbombas [C][COUNT F40.0, 
    ROWPCT.COUNT PCT40.1] + ag_rreservorio [C][COUNT F40.0, ROWPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=ag_rsfertirri ag_rbombas ag_rreservorio ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='DISTRIBUCIÓN DE TECNOLOGÍAS DE RIEGO QUE LOS PRODUCTORES AGROPECUARIOS USAN PARA SUS ACTIVIDADES, POR TIPO DE TECNOLOGÍA'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 45. ORIENTACIÓN SOCIAL DEL SISTEMA DE RIEGO QUE UTILIZAN LOS PRODUCTORES AGROPECUARIOS, POR TIPO DE ORIENTACIÓN SOCIAL.

CTABLES
  /VLABELS VARIABLES=plag_sistema_riego DISPLAY=LABEL
  /TABLE plag_sistema_riego [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=plag_sistema_riego ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='ORIENTACIÓN SOCIAL DEL SISTEMA DE RIEGO QUE UTILIZAN LOS PRODUCTORES AGROPECUARIOS, POR TIPO DE ORIENTACIÓN SOCIAL'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 46. SISTEMAS DE RIEGO QUE CUENTAN CON ESTACIONES DE BOMBEO.

CTABLES
  /VLABELS VARIABLES=plag_bombeo DISPLAY=LABEL
  /TABLE plag_bombeo [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=plag_bombeo ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='SISTEMAS DE RIEGO QUE CUENTAN CON ESTACIONES DE BOMBEO'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.


***** TABLA 47. PERTENENCIA DE LOS PRODUCTORES AGROPECUARIOS A ALGUNA JUNTA DE RIEGO.

CTABLES
  /VLABELS VARIABLES=plag_junta_riego DISPLAY=LABEL
  /TABLE plag_junta_riego [COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=plag_junta_riego ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='PERTENENCIA DE LOS PRODUCTORES AGROPECUARIOS A ALGUNA JUNTA DE RIEGO'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2017-2018'.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.

*** GUARDAR BASE DEL MÓDULO AMBIENTAL (ambnac2018.sav) ***

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.

***** TABLA 48. INTENSIDAD DE USO DE FERTILIZANTES POR CULTIVOS TRANSITORIOS (kg / ha y l / ha)

*** ABRIR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav)***.

DATASET ACTIVATE transitorios.

* CERRAR BASE DEL MÓDULO AMBIENTAL (ambnac2018.sav) ***

DATASET CLOSE ambientales.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

* Transformación a Kilogramos. Litros -  NPK
* MASA - VOLUMEN   /  Kilogramos - Litros

DO IF (ct_umed_npk_fq = 1).
    COMPUTE NPK_Masa=ct_cantidad_npk_fq * 0.453592.
ELSE IF (ct_umed_npk_fq = 2).
    COMPUTE NPK_Masa=ct_cantidad_npk_fq .
ELSE IF (ct_umed_npk_fq = 3).
    COMPUTE NPK_Masa=ct_cantidad_npk_fq * 45.359237.
ELSE IF (ct_umed_npk_fq = 4).
    COMPUTE NPK_Masa=ct_cantidad_npk_fq * 1000.
ELSE IF (ct_umed_npk_fq = 5).
    COMPUTE NPK_Volum=ct_cantidad_npk_fq .
END IF.

* Transformación a Kilogramos. Litros -  NITROGENADOS 
* MASA - VOLUMEN   /  Kilogramos - Litros

DO IF (ct_umed_nit_fq = 1).
    COMPUTE Nitr_Masa=ct_cantidad_nit_fq * 0.453592.
ELSE IF (ct_umed_nit_fq = 2).
    COMPUTE Nitr_Masa=ct_cantidad_nit_fq .
ELSE IF (ct_umed_nit_fq = 3).
    COMPUTE Nitr_Masa=ct_cantidad_nit_fq * 45.359237.
ELSE IF (ct_umed_nit_fq = 4).
    COMPUTE Nitr_Masa=ct_cantidad_nit_fq * 1000.
ELSE IF (ct_umed_nit_fq = 5).
    COMPUTE Nitr_Volum=ct_cantidad_nit_fq .
END IF.

* Transformación a Kilogramos. Litros -  FOSFATADOS 
* MASA - VOLUMEN   /  Kilogramos - Litros

DO IF (ct_umed_fq = 1).
    COMPUTE Fosf_Masa=ct_cantidad_fq * 0.453592.
ELSE IF (ct_umed_fq = 2).
    COMPUTE Fosf_Masa=ct_cantidad_fq .
ELSE IF (ct_umed_fq = 3).
    COMPUTE Fosf_Masa=ct_cantidad_fq * 45.359237.
ELSE IF (ct_umed_fq = 4).
    COMPUTE Fosf_Masa=ct_cantidad_fq * 1000.
ELSE IF (ct_umed_fq = 5).
    COMPUTE Fosf_Volum=ct_cantidad_fq .
END IF.

* Transformación a Kilogramos. Litros -  POTASICOS 
* MASA - VOLUMEN   /  Kilogramos - Litros

DO IF (ct_umed_pot_fq = 1).
    COMPUTE Pot_Masa=ct_cantidad_pot_fq * 0.453592.
ELSE IF (ct_umed_pot_fq = 2).
    COMPUTE Pot_Masa=ct_cantidad_pot_fq .
ELSE IF (ct_umed_pot_fq = 3).
    COMPUTE Pot_Masa=ct_cantidad_pot_fq * 45.359237.
ELSE IF (ct_umed_pot_fq = 4).
    COMPUTE Pot_Masa=ct_cantidad_pot_fq * 1000.
ELSE IF (ct_umed_pot_fq = 5).
    COMPUTE Pot_Volum=ct_cantidad_pot_fq .
END IF.

* Determinación de filtros para superficies con cantidades positivas de fertilizantes.

WEIGHT OFF.

COMPUTE Fil_NPK_Masa = (NPK_Masa > 0).
COMPUTE Fil_NPK_Volum = (NPK_Volum > 0).
COMPUTE Fil_Nitr_Masa = (Nitr_Masa > 0).
COMPUTE Fil_Nitr_Volum = (Nitr_Volum > 0).
COMPUTE Fil_Fosf_Masa = (Fosf_Masa > 0).
COMPUTE Fil_Fosf_Volum = (Fosf_Volum > 0).
COMPUTE Fil_Pot_Masa = (Pot_Masa > 0).
COMPUTE Fil_Pot_Volum = (Pot_Volum > 0).

* Determinación de filtros para unicidad de superficies con cantidades positivas de fertilizantes.

COMPUTE Sup_MASA = (Fil_NPK_Masa | Fil_Nitr_Masa | Fil_Fosf_Masa | Fil_Pot_Masa).
COMPUTE Sup_VOL = (Fil_NPK_Volum | Fil_Nitr_Volum | Fil_Fosf_Volum | Fil_Pot_Volum).

* Determinación de totales de superficie donde se aplicó fertilizantes sólidos (masa) y líquidos (volumen).

COMPUTE Suma_Fert_Masa = SUM.1(NPK_Masa, Nitr_Masa, Fosf_Masa, Pot_Masa).
COMPUTE Suma_Fert_Vol = SUM.1(NPK_Volum, Nitr_Volum, Fosf_Volum, Pot_Volum).

* Determinación de variables contenedoras de los cultivos transitorios para publicación de intensidades de fertilizantes.

IF (ct_clacul = 507) Cultiv_T = 2.
IF (ct_clacul = 509) Cultiv_T = 3.
IF (ct_clacul = 511) Cultiv_T = 4.
IF (ct_clacul = 516) Cultiv_T = 5.
IF (ct_clacul = 519) Cultiv_T = 6.
IF (ct_clacul = 520) Cultiv_T = 7.
IF (ct_clacul = 530) Cultiv_T = 8.
IF (ct_clacul = 532) Cultiv_T = 9.
IF (ct_clacul = 537) Cultiv_T = 10.
IF (ct_clacul = 539) Cultiv_T = 11.
IF (ct_clacul = 547) Cultiv_T = 12.
IF (ct_clacul = 548) Cultiv_T = 13.
IF (ct_clacul = 550) Cultiv_T = 14.
IF (ct_clacul = 551) Cultiv_T = 15.
IF (ct_clacul = 554) Cultiv_T = 16.
IF (ct_clacul = 561) Cultiv_T = 17.
IF (ct_clacul = 567) Cultiv_T = 18.
IF (ct_clacul = 573) Cultiv_T = 19.
IF (ct_clacul = 575) Cultiv_T = 20.
IF (ct_clacul = 576) Cultiv_T = 21.
IF (ct_clacul = 577) Cultiv_T = 22.
IF (ct_clacul = 579) Cultiv_T = 23.

IF RANGE(ct_clacul, 500, 506) Cultiv_T = 24.
IF (ct_clacul = 508) Cultiv_T = 24.
IF (ct_clacul = 510) Cultiv_T = 24.
IF RANGE(ct_clacul, 512, 515) Cultiv_T = 24.
IF (ct_clacul = 517) Cultiv_T = 24.
IF (ct_clacul = 518) Cultiv_T = 24.
IF RANGE(ct_clacul, 521, 529) Cultiv_T = 24.
IF (ct_clacul = 531) Cultiv_T = 24.
IF RANGE(ct_clacul, 533, 536) Cultiv_T = 24.
IF (ct_clacul = 538) Cultiv_T = 24.
IF RANGE(ct_clacul, 540, 546) Cultiv_T = 24.
IF (ct_clacul = 549) Cultiv_T = 24.
IF (ct_clacul = 552) Cultiv_T = 24.
IF (ct_clacul = 553) Cultiv_T = 24.
IF RANGE(ct_clacul, 555, 560, 562, 566) Cultiv_T = 24.
IF RANGE(ct_clacul, 568, 572) Cultiv_T = 24.
IF (ct_clacul = 574) Cultiv_T = 24.
IF (ct_clacul = 578) Cultiv_T = 24.
IF RANGE(ct_clacul, 580, 583) Cultiv_T = 24.
IF RANGE(ct_clacul, 586, 597) Cultiv_T = 24.
IF (ct_clacul = 599) Cultiv_T = 24.

IF (RANGE(ct_clacul, 500, 599) & ~ANY(ct_clacul, 584, 585, 598)) NACIONAL = 1.

VALUE LABELS Cultiv_T
2"ARROZ (EN CÁSCARA)"
3"ARVEJA SECA (GRANO SECO)"
4"ARVEJA TIERNA (VAINA)"
5"BROCOLI (REPOLLO)"
6"CEBADA (GRANO SECO)"
7"CEBOLLA BLANCA (TALLO FRESCO)"
8"FRÉJOL SECO (GRANO SECO)"
9"FRÉJOL TIERNO (VAINA)"
10"HABA SECA (GRANO SECO)"
11"HABA TIERNA (VAINA)"
12"MAÍZ DURO CHOCLO (CHOCLO)"
13"MAÍZ DURO SECO (GRANO SECO)"
14"MAÍZ SUAVE CHOCLO (CHOCLO)"
15"MAÍZ SUAVE SECO (GRANO SECO)"
16"MANÍ (GRANO DESCASCARADO)"
17"PAPA"
18"QUINUA"
19"SOYA"
20"TABACO"
21"TOMATE RIÑÓN"
22"TRIGO"
23"YUCA"
24"OTROS TRANSITORIOS".
EXECUTE.

WEIGHT BY fact_exp_fin.

* TABLA A. Cantidades de masa (kg) y volumen (l) aplicados a los cultivos transitorios, por ciertos cultivos transitorios y según clase de fertilizante químico.

CTABLES
  /VLABELS VARIABLES=NACIONAL Cultiv_T Fil_NPK_Masa NPK_Masa Fil_NPK_Volum NPK_Volum Fil_Nitr_Masa Nitr_Masa Fil_Nitr_Volum Nitr_Volum
    Fil_Fosf_Masa Fosf_Masa Fil_Fosf_Volum Fosf_Volum Fil_Pot_Masa Pot_Masa Fil_Pot_Volum Pot_Volum Suma_Fert_Masa Suma_Fert_Vol DISPLAY=LABEL
  /TABLE NACIONAL + Cultiv_T BY Fil_NPK_Masa > NPK_Masa [SUM] + Fil_NPK_Volum > NPK_Volum [SUM] + Fil_Nitr_Masa > Nitr_Masa [SUM] 
    + Fil_Nitr_Volum > Nitr_Volum [SUM] + Fil_Fosf_Masa > Fosf_Masa [SUM] + Fil_Fosf_Volum > Fosf_Volum [SUM] + Fil_Pot_Masa > Pot_Masa [SUM] 
    + Fil_Pot_Volum > Pot_Volum [SUM] + Suma_Fert_Masa [SUM] + Suma_Fert_Vol [SUM]
  /CATEGORIES VARIABLES=NACIONAL Fil_NPK_Masa Fil_NPK_Volum Fil_Nitr_Masa Fil_Nitr_Volum Fil_Fosf_Masa Fil_Fosf_Volum Fil_Pot_Masa
    Fil_Pot_Volum ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=Cultiv_T ORDER=A KEY=VALUE EMPTY=INCLUDE
  /TITLES
    TITLE='MASA (kg) Y VOLUMEN (l) USADOS DE FERTILIZANTES, POR CIERTOS CULTIVOS TRANSITORIOS Y SEGÚN CLASE DE FERTILIZANTE QUÍMICO'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2018'.

* TABLA B. Superficie con aplicación de fertilizantes, por ciertos cultivos transitorios y según clase de fertilizante químico (en masa y volumen).

CTABLES
  /VLABELS VARIABLES=NACIONAL Cultiv_T ct_k510h Fil_NPK_Masa Fil_NPK_Volum Fil_Nitr_Masa Fil_Nitr_Volum Fil_Fosf_Masa Fil_Fosf_Volum
    Fil_Pot_Masa Fil_Pot_Volum Sup_MASA Sup_VOL DISPLAY=LABEL
  /TABLE NACIONAL [C] + Cultiv_T [C] BY ct_k510h [SUM] > (Fil_NPK_Masa [C] + Fil_NPK_Volum [C] + Fil_Nitr_Masa [C] + Fil_Nitr_Volum [C]
   + Fil_Fosf_Masa [C] + Fil_Fosf_Volum [C] + Fil_Pot_Masa [C] + Fil_Pot_Volum [C] + Sup_MASA + Sup_VOL)
  /CATEGORIES VARIABLES=NACIONAL Fil_NPK_Masa Fil_NPK_Volum Fil_Nitr_Masa Fil_Nitr_Volum Fil_Fosf_Masa Fil_Fosf_Volum Fil_Pot_Masa
   Fil_Pot_Volum Sup_MASA Sup_VOL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=Cultiv_T ORDER=A KEY=VALUE EMPTY=INCLUDE
  /TITLES
    TITLE='SUPERFICIE CON APLICACIÓN DE FERTILIZANTES, POR CIERTOS CULTIVOS TRANSITORIOS Y SEGÚN CLASE DE FERTILIZANTE QUÍMICO' '(ha)'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2018'.

* ############################################################################################################
*** NOTA IMPORTANTE: PARA OBTENER LA TABLA 48, SE DEBE DIVIDIR (CELDA A CELDA) LA TABLA A PARA LA TABLA B.
* ############################################################################################################

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

*** GUARDAR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ****

*------------------------------------------------------------------------------------------------------------------------------------------------------------------------.


***** TABLA 49. INTENSIDAD DE USO DE FERTILIZANTES POR CULTIVOS PERMANENTES (kg/ ha y l/ha)

*** ABRIR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav)***.

DATASET ACTIVATE permanentes.

*** CERRAR BASE DE CULTIVOS TRANSITORIOS (ctnac2018.sav) ****

DATASET CLOSE transitorios.

FILTER OFF.
USE ALL.
SPLIT FILE OFF.
WEIGHT OFF.

* Transformación a Kilogramos. Litros - NPK  
* MASA - VOLUMEN   /  Kilogramos - Litros

DO IF (cp_umed_npk_fq = 1).
    COMPUTE NPK_Masa=cp_cantidad_npk_fq * 0.453592.
ELSE IF (cp_umed_npk_fq = 2).
    COMPUTE NPK_Masa=cp_cantidad_npk_fq .
ELSE IF (cp_umed_npk_fq = 3).
    COMPUTE NPK_Masa= cp_cantidad_npk_fq * 45.359237.
ELSE IF (cp_umed_npk_fq = 4).
    COMPUTE NPK_Masa=cp_cantidad_npk_fq * 1000.
ELSE IF (cp_umed_npk_fq = 5).
    COMPUTE NPK_Volum=cp_cantidad_npk_fq .
END IF.

* Transformación a Kilogramos. Litros -  NITROGENADOS 
* MASA - VOLUMEN   /  Kilogramos - Litros

DO IF (cp_umed_nit_fq = 1).
    COMPUTE Nitr_Masa=cp_cantidad_nit_fq * 0.453592.
ELSE IF (cp_umed_nit_fq = 2).
    COMPUTE Nitr_Masa=cp_cantidad_nit_fq .
ELSE IF (cp_umed_nit_fq = 3).
    COMPUTE Nitr_Masa=cp_cantidad_nit_fq * 45.359237.
ELSE IF (cp_umed_nit_fq = 4).
    COMPUTE Nitr_Masa=cp_cantidad_nit_fq * 1000.
ELSE IF (cp_umed_nit_fq = 5).
    COMPUTE Nitr_Volum=cp_cantidad_nit_fq .
END IF.

* Transformación a Kilogramos. Litros -  FOSFATADOS 
* MASA - VOLUMEN   /  Kilogramos - Litros"

DO IF (cp_umed_fq = 1).
    COMPUTE Fosf_Masa=cp_cantidad_fq * 0.453592.
ELSE IF (cp_umed_fq = 2).
    COMPUTE Fosf_Masa=cp_cantidad_fq .
ELSE IF (cp_umed_fq = 3).
    COMPUTE Fosf_Masa=cp_cantidad_fq * 45.359237.
ELSE IF (cp_umed_fq = 4).
    COMPUTE Fosf_Masa=cp_cantidad_fq * 1000.
ELSE IF (cp_umed_fq = 5).
    COMPUTE Fosf_Volum=cp_cantidad_fq .
END IF.

* Transformación a Kilogramos. Litros -  POTASICOS 
*  MASA - VOLUMEN   /  Kilogramos - Litros

DO IF (cp_umed_pot_fq = 1).
    COMPUTE Pot_Masa=cp_cantidad_pot_fq * 0.453592.
ELSE IF (cp_umed_pot_fq = 2).
    COMPUTE Pot_Masa=cp_cantidad_pot_fq .
ELSE IF (cp_umed_pot_fq = 3).
    COMPUTE Pot_Masa=cp_cantidad_pot_fq * 45.359237.
ELSE IF (cp_umed_pot_fq = 4).
    COMPUTE Pot_Masa=cp_cantidad_pot_fq * 1000.
ELSE IF (cp_umed_pot_fq = 5).
    COMPUTE Pot_Volum=cp_cantidad_pot_fq .
END IF.

* Determinación de filtros para superficies con cantidades positivas de fertilizantes.

WEIGHT OFF.

COMPUTE Fil_NPK_Masa = (NPK_Masa > 0).
COMPUTE Fil_NPK_Volum = (NPK_Volum > 0).
COMPUTE Fil_Nitr_Masa = (Nitr_Masa > 0).
COMPUTE Fil_Nitr_Volum = (Nitr_Volum > 0).
COMPUTE Fil_Fosf_Masa = (Fosf_Masa > 0).
COMPUTE Fil_Fosf_Volum = (Fosf_Volum > 0).
COMPUTE Fil_Pot_Masa = (Pot_Masa > 0).
COMPUTE Fil_Pot_Volum = (Pot_Volum > 0).

* Determinación de filtros para unicidad de superficies con cantidades positivas de fertilizantes.

COMPUTE Sup_MASA = (Fil_NPK_Masa | Fil_Nitr_Masa | Fil_Fosf_Masa | Fil_Pot_Masa).
COMPUTE Sup_VOL = (Fil_NPK_Volum | Fil_Nitr_Volum | Fil_Fosf_Volum | Fil_Pot_Volum).

* Determinación de totales de superficie donde se aplicó fertilizantes sólidos (masa) y líquidos (volumen).

COMPUTE Suma_Fert_Masa = SUM.1(NPK_Masa, Nitr_Masa, Fosf_Masa, Pot_Masa).
COMPUTE Suma_Fert_Vol = SUM.1(NPK_Volum, Nitr_Volum, Fosf_Volum, Pot_Volum).

* Determinación de variables contenedoras de los cultivos permanentes para publicación de intensidades de fertilizantes.

IF (rc_clacul = 402) Cultiv_P = 2.
IF (rc_clacul = 407) Cultiv_P = 3.
IF (rc_clacul = 411) Cultiv_P = 4.
IF (rc_clacul = 416) Cultiv_P = 5.
IF (rc_clacul = 419) Cultiv_P = 6.
IF (rc_clacul = 420) Cultiv_P = 7.
IF (rc_clacul = 440) Cultiv_P = 8.
IF (rc_clacul = 444) Cultiv_P = 9.
IF (rc_clacul = 446) Cultiv_P = 10.
IF (rc_clacul = 450) Cultiv_P = 11.
IF (rc_clacul = 453) Cultiv_P = 12.
IF (rc_clacul = 456) Cultiv_P = 13.
IF (rc_clacul = 457) Cultiv_P = 14.
IF (rc_clacul = 464) Cultiv_P = 15.
IF (rc_clacul = 466) Cultiv_P = 16.
IF (rc_clacul = 472) Cultiv_P = 17.

IF (rc_clacul = 400) Cultiv_P = 18.
IF (rc_clacul = 401) Cultiv_P = 18.
IF RANGE(rc_clacul, 403, 406, 408, 410, 412, 415) Cultiv_P = 18.
IF (rc_clacul = 417) Cultiv_P = 18.
IF (rc_clacul = 418) Cultiv_P = 18.
IF RANGE(rc_clacul, 421, 439, 441, 443) Cultiv_P = 18.
IF (rc_clacul = 445) Cultiv_P = 18.
IF RANGE(rc_clacul, 447, 449) Cultiv_P = 18.
IF (rc_clacul = 451) Cultiv_P = 18.
IF (rc_clacul = 452) Cultiv_P = 18.
IF (rc_clacul = 454) Cultiv_P = 18.
IF (rc_clacul = 455) Cultiv_P = 18.
IF RANGE(rc_clacul, 458, 463) Cultiv_P = 18.
IF (~ANY(Identificador, "14045401017470001", "14045401017470002") & (rc_clacul = 465)) Cultiv_P = 18.
IF RANGE(rc_clacul, 468, 471, 473, 477, 480, 497) Cultiv_P = 18.
IF (rc_clacul = 499) Cultiv_P = 18.
IF (RANGE(rc_clacul, 400, 499) & ~ANY(Identificador, "14045401017470001", "14045401017470002") & ~ANY(rc_clacul, 467, 478, 479, 498)) NACIONAL = 1.

VALUE LABELS Cultiv_P
2"AGUACATE"
3"BANANO"
4"CACAO CCN51 (ALMENDRA SECA)"
5"CAFÉ ARÁBIGO (GRANO ORO)"
6"CAÑA DE AZÚCAR / AZÚCAR"
7"CAÑA DE AZÚCAR / OTROS USOS"
8"LIMON"
9"MANGO"
10"MARACUYÁ"
11"NARANJA"
12"ORITO"
13"PALMA AFRICANA"
14"PALMITO"
15"PIÑA"
16"PLÁTANO"
17"TOMATE DE ÁRBOL"
18"OTROS PERMANENTES".
EXECUTE.

WEIGHT BY fact_exp_fin.

* TABLA C. Cantidades de masa (kg) y volumen (l) aplicados a los cultivos permanentes, por ciertos cultivos transitorios y según clase de fertilizante químico.

CTABLES
  /VLABELS VARIABLES=NACIONAL Cultiv_P Fil_NPK_Masa NPK_Masa Fil_NPK_Volum NPK_Volum Fil_Nitr_Masa Nitr_Masa Fil_Nitr_Volum Nitr_Volum
    Fil_Fosf_Masa Fosf_Masa Fil_Fosf_Volum Fosf_Volum Fil_Pot_Masa Pot_Masa Fil_Pot_Volum Pot_Volum Suma_Fert_Masa Suma_Fert_Vol DISPLAY=LABEL
  /TABLE NACIONAL + Cultiv_P BY Fil_NPK_Masa > NPK_Masa [SUM] + Fil_NPK_Volum > NPK_Volum [SUM] + Fil_Nitr_Masa > Nitr_Masa [SUM] 
    + Fil_Nitr_Volum > Nitr_Volum [SUM] + Fil_Fosf_Masa > Fosf_Masa [SUM] + Fil_Fosf_Volum > Fosf_Volum [SUM] + Fil_Pot_Masa > Pot_Masa [SUM] 
    + Fil_Pot_Volum > Pot_Volum [SUM] + Suma_Fert_Masa [SUM] + Suma_Fert_Vol [SUM]
  /CATEGORIES VARIABLES=NACIONAL Fil_NPK_Masa Fil_NPK_Volum Fil_Nitr_Masa Fil_Nitr_Volum Fil_Fosf_Masa Fil_Fosf_Volum Fil_Pot_Masa
    Fil_Pot_Volum ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=Cultiv_P ORDER=A KEY=VALUE EMPTY=INCLUDE
  /TITLES
    TITLE='MASA (kg) Y VOLUMEN (l) USADOS DE FERTILIZANTES, POR CIERTOS CULTIVOS PERMANENTES Y SEGÚN CLASE DE FERTILIZANTE QUÍMICO'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2018'.

* TABLA D. Superficie con aplicación de fertilizantes, por ciertos cultivos permanentes y según clase de fertilizante químico (en masa y volumen).

CTABLES
  /VLABELS VARIABLES=NACIONAL Cultiv_P cp_k409ha Fil_NPK_Masa Fil_NPK_Volum Fil_Nitr_Masa Fil_Nitr_Volum Fil_Fosf_Masa Fil_Fosf_Volum
    Fil_Pot_Masa Fil_Pot_Volum Sup_MASA Sup_VOL DISPLAY=LABEL
  /TABLE NACIONAL [C] + Cultiv_P [C] BY cp_k409ha [SUM] > (Fil_NPK_Masa [C] + Fil_NPK_Volum [C] + Fil_Nitr_Masa [C] + Fil_Nitr_Volum [C]
   + Fil_Fosf_Masa [C] + Fil_Fosf_Volum [C] + Fil_Pot_Masa [C] + Fil_Pot_Volum [C] + Sup_MASA + Sup_VOL)
  /CATEGORIES VARIABLES=NACIONAL Fil_NPK_Masa Fil_NPK_Volum Fil_Nitr_Masa Fil_Nitr_Volum Fil_Fosf_Masa Fil_Fosf_Volum Fil_Pot_Masa
   Fil_Pot_Volum Sup_MASA Sup_VOL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=Cultiv_P ORDER=A KEY=VALUE EMPTY=INCLUDE
  /TITLES
    TITLE='SUPERFICIE CON APLICACIÓN DE FERTILIZANTES, POR CIERTOS CULTIVOS PERMANENTES Y SEGÚN CLASE DE FERTILIZANTE QUÍMICO' '(ha)'
    CAPTION='Elaboración: INEC' 'Fuente: Encuesta de Superficie y Producción Agropecuaria Continua 2018'.

* ############################################################################################################
*** NOTA IMPORTANTE: PARA OBTENER LA TABLA 49, SE DEBE DIVIDIR (CELDA A CELDA) LA TABLA C PARA LA TABLA D.
* ############################################################################################################

FILTER OFF.
USE ALL.
WEIGHT OFF.
SPLIT FILE OFF.

*** GUARDAR BASE DE CULTIVOS PERMANENTES (cpnac2018.sav) ****

*/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
* FIN DE LA SINTAXIS DE TABULADOS DEL MÓDULO AMBIENTAL - ESPAC 2018.
*\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\


